function VALS=affine(A,b,S)              %last updated 7/2/98
%AFFINE  Computes the affine transformation T(v) = Av + b
%        where A is a 2 by 2 matrix, b is a 2 by 1 matrix
%        and v is a 2 by 1 vector a set of such vectors.
%
%        Use in the form:   ==> vals = affine(A,b,S)  <==
%        with 
%             A a 2 by 2 matrix
%             b a 2 by 1 matrix
%             S a 2 by n set of points from the plane
%                   row 1 of S contains the x-coordinates
%                   row 2 of S contains the y-coordinates
%        upon execution vals contains the the images of the points in S   
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

[m,n]=size(A);
if m~=2 | n~=2
   disp('ERROR: Matrix A must be 2 by 2.')
   return
end
b=b(:);
[m,n]=size(b);
if m~=2 | n~=1
   disp('ERROR: Vector b must be 2 by 1.')
   return
end   

[m,n]=size(S);
if m~=2 
   disp('ERROR: Data in matrix S must have 2 rows.')
   return
end 

B=[b(1)*ones(1,n);b(2)*ones(1,n)];

VALS=A*S+B;
 