function areapara(uin,vin)      %9/14/98; 12/11/2006; 6/24/2015
%AREAPARA  The area of a parallelogram using elimination.
%          The vectors u and v in 2-space determine a parallelogram.
%          We show the algebraic elimination steps which yield
%          a rectangle with the same area. At each step the corresponding
%          geometric figure is displayed.
%
%    Use in the form   ==>  areapara(u,v)  <==
%          where u and v are vectors in 2-space
%
%    or in the form    ==>  areapara  <==
%          in which case you will be prompted for input or you may
%          choose a demo.
%
%          Requires mat2strh routine.
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%GLOBAL VARIABLES
global origA

%Vertical position of labels and matrix entries
vpos=[1 .92 .86 .80 .72 .66 .60 .52 .46 .40 .32 .26];

%Strings   *************************************************************
label1='Original Matrix';
label2='After First Elimination.';
label3='After Second Elimination.';
cont=' Press ENTER to Continue.';
contend='Press ENTER to QUIT.';
mess1='Drawing original vectors and displaying the matrix.';
mess2='The original parallelogram.';
mess3='Drawing vectors after the first elimination.';
mess4='Coloring the new parallelogram.';
mess5='Drawing vectors after the second elimination.';
mess6='Realigning outlined regions.';
mess7a=' ';
%mess7a='Area of the original parallelogram =';
mess7b='Area of the rectangle.';
mess8='Compute the absolute value of the determinants of the 3 matrices.';

s0=' ';
s1='   Enter your choice:  ==>  ';
s2='The vectors are multiples of one another.';
s3='Restart the routine and select different vectors.';
head1='Area of a PARALLELOGRAM by ELIMINATION';
menu1=['             << OPTIONS  >>          ';
       '                                     ';
       '1. See a demo using vectors          ';
       '       u = [8 2], v = [-4 5]         ';
       '                                     ';
       '2. See a demo using vectors          ';
       '       u = [-7 6], v = [5 -9]        ';
       '                                     ';
       '3. Enter your own pair of vectors.   ';
       '                                     ';
       '4. See help information.             ';
       '                                     ';
       '0. Quit.                             '];
%*************************************************************************


if nargin==0
   goodch='N';
   while goodch=='N'
      clc,disp([blanks(10) head1]),disp(s0),disp(s0)
      disp(menu1),disp(s0)
      ch=input(s1);
      if isempty(ch)==1,ch=999;end
      if ch==4,clc,help areapara,disp(s0),disp(cont),pause,end
      if ch==0,return,end
      if ch==1,uin=[8 2];vin=[-4 5];goodch='Y';end
      if ch==2,uin=[-7 6];vin=[5 -9];goodch='Y';end
      if ch==3
         goodch='Y';
         goodu='N';
         while goodu=='N'
            uin=input('Enter a nonzero vector with two components ==> ');
            uin=uin(:)';
            if length(uin)==2 & norm(uin)~=0
               goodu='Y';
            else
               disp('Re-enter vector u'),pause(3)
            end
         end
         goodv='N';
         while goodv=='N'
            vin=input('Enter a nonzero vector with two components ==> ');
            vin=vin(:)';
            if length(vin)==2 & norm(vin)~=0
               goodv='Y';
            else
               disp('Re-enter vector v'),pause(3)
            end
         end        
      end
   end
end

if nargin==1 | nargin>2
   disp('ERROR in number of input parameters.')
   return
end

%'PIVOT' the vectors
%If we use 'partial pivoting' (write the vector with the largest
%x-component as the first vector which we call u), then the new
%second row after elimination can be shown to be a convex linear
%combination of u and u+v. Hence the new vertical basis vector
%is positioned so we can chop/substitute conguent triangles to show 
%the preservation of area from the first parallelogram to the second.

if abs(uin(1))>abs(vin(1))
   u=uin;v=vin;
else
   v=uin;u=vin;
end
if uin(1)==vin(1)
   if abs(uin(2))<abs(vin(2))
      u=uin;v=vin;
   else
      u=vin;v=uin;
   end
end


%Check if vectors are independent
A=[u;v];
if det(A)==0,clc,disp(s0),disp(s2),disp(s0),disp(s3),return,end

%Want A(1,1) in matrix A below to be nonzero so we can do elimination
if u(1)==0, temp=v;v=u;u=temp;end

upv=u+v; %sum of the vectors

A=[u;v]; %defining the matrix

sc(1)=max(max(abs(A)));  %vector sc is used to determine 
                         %size of sketching region

Anew=A;
Anew(2,:)=(-Anew(2,1)/Anew(1,1))*Anew(1,:)+Anew(2,:);
Anew(2,1)=0; %setting eliminated entry to zero
%done first row op

sc(2)=max(max(abs(Anew)));

%do second row op
Anew1=Anew;
Anew1(1,:)=(-Anew1(1,2)/Anew1(2,2))*Anew1(2,:)+Anew1(1,:);
Anew1(1,2)=0; %Setting eliminated entry to zero
sc(3)=max(max(abs(Anew1)));
sc(4)=abs(Anew(2,1))+abs(Anew(1,1));
sc(5)=abs(Anew(2,2))+abs(Anew(1,2));
sc(6)=max(abs(upv));
rval=max(sc);
rval=fix(rval)+1; %added 12/11/06 to get integer labels on axes
rect=[-rval rval -rval rval];%setting graph "window" size

%setting up matrix displays
matA=mat2strh(A,2);
matAnew=mat2strh(Anew,2);
matAnew1=mat2strh(Anew1,2);

%INITIALIZING FIGURE ************************************************       
bkgr='white';  %BACKGROUND COLOR
figh=figure('Color',bkgr,'units','normal','position',[0 0 1 1]);
 %setting graphics window to full size
%setting up axes
%
pgrf=axes('position',[.45 .3 .55 .55]);
titleax=axes('position',[.1 .95 .8 .05]);axis('off');
messax=axes('position',[.45 .25 .45 .1]);axis('off'); %changed for movie
vanax=axes('position',[.8 .02 .08 .15]);axis('off');
matrixax=axes('position',[.01 .2 .28 .7]);axis('off');

%setup figure axis
axes(pgrf);axis(rect);axis('square');
set(pgrf,'xtick',[-rval:2:rval],'ytick',[-rval:2:rval],...
    'xgrid','off','ygrid','off');
lh1=line([-rval rval],[0 0],'Color','k');
hold on
lh2=line([0 0],[-rval rval],'Color','k');

%pause %recording pause
%**********************************************************************

if abs(Anew(2,2))<abs(Anew(1,2))     %inserted 6/9/96
                                     %if this is false we can use triangle
                                     %chop/substitution at both the top &
                                     %bottom to go from 2nd parallelogram
                                     %to the rectangle.
   triang='N';
   %determine orientation of second parallelogram; left or right
   %of y-axis. Set sign of radius of circle to be drawn later.
   if Anew(1,1)>0
      sgnrad=1;    %to the right
   else
      sgnrad=-1;   %to the left
   end

else
   triang='Y';

   %setting up orientation codes for pieces later ************************
   if Anew(2,2)>0
      direc='u';  %Up direction for second vector after 1st elimination
   else
      direc='d';  %Down direction
   end
   %determining quadrant of first vector
   if u(1)>=0 & u(2)<=0, quad='4';end
   if u(1)<=0 & u(2)<=0, quad='3';end
   if u(1)>=0 & u(2)>=0, quad='1';end
   if u(1)<=0 & u(2)>=0, quad='2';end
   %determining whether we chop triangle portion at origin(O)
   % or opposite end(E)
   type='E';
   if direc=='u' & (quad=='3' | quad=='4'), type='O';end
   if direc=='d' & (quad=='2' | quad=='1'), type='O';end
end

%*************************************************************************

%putting title ***********************************************************
axes(titleax);
text(0,0,head1,'color','r','fontweight','bold','fontsize',16);
pause(2)
%*************************************************************************

%displaying first message*************************************************
axes(messax)
mh=text(0,0,mess1,'unit','normal','color','b','fontsize',14,...
        'fontweight','bold'); 

%*************************************************************************

%vanity
axes(vanax);
van=text(0,0,'by D.R.Hill','unit','normal',...
     'color','black','fontsize',14,'fontweight','bold',...
     'fontangle','oblique');
drawnow

%drawing original vectors
axes(pgrf);
uvec=line([0 u(1)],[0 u(2)],'color','r','linewidth',2);
%sizarr=10;
%uvec=arrow([0 0],[u(1) u(2)],...
%         sizarr,'BaseAngle',60,'facecolor','y','edgecolor','r','linewidth',2);
vvec=line([0 v(1)],[0 v(2)],'color','b','linewidth',2);
%vvec=arrow([0 0],[v(1) v(2)],...
%         sizarr,'BaseAngle',60,'facecolor','y','edgecolor','b','linewidth',2);

%first display
axes(matrixax);
ld1=text(0,vpos(1),label1,'unit','normal',...
          'color','k','fontsize',16,'fontweight','bold');
ld2=text(0,vpos(2),matA(1,:),'unit','normal',...
           'color','r','fontsize',16,'fontweight','bold');
ld3=text(0,vpos(3),matA(2,:),'unit','normal',...
           'color','b','fontsize',16,'fontweight','bold');

%To continue message
mhcont=text(0,0,cont,'units','normal','color','k','fontsize',14,...
            'fontweight','bold');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');

%Displaying second message
set(mh,'string',mess2,'unit','normal','color','b');
pause(2)

%Doing original parallelogram patch
axes(pgrf);
para=patch([0 u(1) upv(1) v(1) 0],[0 u(2) upv(2) v(2) 0],'m');
pause(2)

%Deleting the original vectors
delete(uvec);delete(vvec);
pause(1)

%Turning off continue message & old message
set(mhcont,'visible','on');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');

%Displaying third message
set(mh,'string',mess3,'unit','normal','color','b');

%second display
axes(matrixax);
ld4=text(0,vpos(4),label2,'unit','normal',...
          'color','k','fontsize',16,'fontweight','bold');
ld5=text(0,vpos(5),matAnew(1,:),'unit','normal',...
          'color','k','fontsize',16,'fontweight','bold');
ld6=text(0,vpos(6),matAnew(2,:),'unit','normal',...
          'color','k','fontsize',16,'fontweight','bold');
pause(3)

%drawing new vectors
axes(pgrf);
newvvec1=line([0 Anew(2,1)],[0 Anew(2,2)],'color','b','linewidth',2);
pause(3)
newvvec2=line([Anew(1,1) Anew(2,1)+Anew(1,1)],...
              [Anew(1,2) Anew(2,2)+Anew(1,2)],'color','b','linewidth',2);
newuvec1=line([Anew(2,1) Anew(2,1)+Anew(1,1)],...
              [Anew(2,2) Anew(2,2)+Anew(1,2)],'color','r','linewidth',2);
pause(3)
%coloring patch to be deleted black
oldtri=patch([0 v(1) Anew(2,1) 0],[0 v(2) Anew(2,2) 0],'k');
pause(2)

%Turning off messages
set(mhcont,'visible','on');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');

%displaying fourth message
set(mh,'string',mess4,'unit','normal','color','b');
pause(2)

%Changing colors ; newregion & old region
axes(pgrf);
set(para,'facecolor',bkgr);
pause(2)
%new region patch
para1=patch([0 Anew(1,1) Anew(2,1)+Anew(1,1) Anew(2,1) 0],...
            [0 Anew(1,2) Anew(2,2)+Anew(1,2) Anew(2,2) 0],'m');
pause(2)
set(para,'edgecolor',bkgr);
pause(2)
%set(oldtri,'facecolor',bkgr);
%pause(1)
%set(oldtri,'edgecolor',bkgr);
delete(oldtri);  %deleting a patch
set(newvvec1,'visible','off');
set(newvvec2,'visible','off');
set(newuvec1,'visible','off');
pause(2)

%turning off messages
set(mhcont,'visible','on');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');

if triang=='Y'
   %third display; shows result of second elim when triangle chop is valid
   axes(matrixax);
   ld7=text(0,vpos(7),label3,'unit','normal',...
             'color','k','fontsize',16,'fontweight','bold');
   ld8=text(0,vpos(8),matAnew1(1,:),'unit','normal',...
             'color','k','fontsize',16,'fontweight','bold');
   ld9=text(0,vpos(9),matAnew1(2,:),'unit','normal',...
             'color','k','fontsize',16,'fontweight','bold');
   pause(2)
end

if triang=='N'
   axes(pgrf);tickm=[-rval:1:rval];
   %set(pgrf,'xcolor','k','xgrid','on','xtickmode','auto',...
   %    'ycolor','k','ygrid','on','ytickmode','auto');  
   %changed for the movie
   if sign(Anew(1,2))==sign(Anew(2,2))
      tr1=patch([0 0 Anew(1,1) 0],...
         [Anew(2,2) Anew(1,2)+Anew(2,2) Anew(1,2)+Anew(2,2) Anew(2,2)],'b');
      tr2=patch([0 Anew(1,1) Anew(1,1) 0],[0 Anew(1,2) 0 0],'b');
      pause(3)
      rline1=line([0 0],[0 Anew(1,2)+Anew(2,2)],'color','g','linewidth',4);
      rline2=line([0 Anew(1,1)],[Anew(1,2)+Anew(2,2) Anew(1,2)+Anew(2,2)],'color','g','linewidth',4);
      rline3=line([Anew(1,1) Anew(1,1)],[Anew(1,2)+Anew(2,2) 0],'color','g','linewidth',4);
      rline4=line([Anew(1,1) 0],[0 0],'color','g','linewidth',4);
      pause(2)      
   else
      tr1=patch([0 0 Anew(1,1) 0],[0 Anew(1,2) Anew(1,2) 0],'b');
      tr2=patch([0 Anew(1,1) Anew(1,1) 0],...
          [Anew(2,2) Anew(1,2)+Anew(2,2) Anew(2,2) Anew(2,2)],'b');
      pause(3)
      rline1=line([0 0],[Anew(1,2),Anew(2,2)],'color','g','linewidth',4);
      rline2=line([0 Anew(1,1)],[Anew(1,2) Anew(1,2)],'color','g','linewidth',4);
      rline3=line([Anew(1,1) Anew(1,1)],[Anew(1,2) Anew(2,2)],'color','g','linewidth',4);
      rline4=line([Anew(1,1) 0],[Anew(2,2) Anew(2,2)],'color','g','linewidth',4);
      pause(2)
   end
   axes(matrixax);
   ld7a=text(0,vpos(7),...
            ['AREA of RECTANGLE =  ' num2str(abs(Anew(1,1))) ' * ' num2str(abs(Anew(1,2))+abs(Anew(2,2)))],...
            'unit','normal','color','g','fontsize',14,'fontweight','bold');
   ld8a=text(0,vpos(8),...
            ['AREA of 2 TRIANGLES = ' num2str(abs(Anew(1,1))) ' * ' num2str(abs(Anew(1,2)))],...
            'unit','normal','color','b','fontsize',14,'fontweight','bold');
   ld9a=text(0,vpos(9),...
            ['              DIFFERENCE = ' num2str(abs(Anew(1,1))) ' * ' num2str(abs(Anew(2,2)))],...
            'unit','normal','color','m','fontsize',14,'fontweight','bold');
   
   pause(2)
   set(mh,'string','INSPECT the FIGURE and MATH carefully.',...
      'unit','normal','color','r');
   pause(2)
   set(mhcont,'visible','on');
   pause
   axes(pgrf);grid off;
   set(mh,'color',bkgr);
   set(mhcont,'visible','off');
   %delete rectangle pieces
   axes(pgrf);
   delete(rline1),delete(rline2),delete(rline3),delete(rline4)
   pause(2)
   delete(tr1),delete(tr2)
   pause(2)
   set(mhcont,'visible','on');
   pause
   set(mhcont,'visible','off');
end

if triang=='Y'
   %doing the triangle chop
   axes(pgrf);
   if type =='O'
      %chopping at origin & moving to end
      tr2=patch([Anew1(2,1) Anew1(1,1) Anew1(1,1) Anew1(2,1)],...
                [Anew1(2,2) Anew(2,2)+Anew(1,2) Anew(2,2) Anew1(2,2)],bkgr);
      pause(2)
      tr1=patch([0 A(1,1) Anew1(1,1) 0],[0 A(1,2) Anew1(1,2) 0], 'k');
      
   else
      %chopping at end & moving to origin
      tr2=patch([0 A(1,1) Anew1(1,1) 0],[0 A(1,2) Anew1(1,2) 0], bkgr);
      pause(2)
      tr1=patch([Anew1(2,1) Anew1(1,1) Anew1(1,1) Anew1(2,1)],...
                [Anew1(2,2) Anew(2,2)+Anew(1,2) Anew(2,2) Anew1(2,2)],'k');
            
   end
end

%displaying message 5
if triang=='N'
   axes(matrixax);
   ld7=text(0,vpos(10),label3,'unit','normal',...
           'color','k','fontsize',16,'fontweight','bold');
   ld8=text(0,vpos(11),matAnew1(1,:),'unit','normal',...
           'color','k','fontsize',16,'fontweight','bold');
   ld9=text(0,vpos(12),matAnew1(2,:),'unit','normal',...
           'color','k','fontsize',16,'fontweight','bold');
   %line outline of rectangle
   axes(pgrf);
   lpara31=line([0 Anew1(1,1)],[0 0],'color','k');
   lpara32=line([Anew1(1,1) Anew1(1,1)],[0 Anew1(2,2)],'color','k');
   lpara33=line([Anew1(1,1) 0],[Anew1(2,2) Anew1(2,2)],'color','k');
   lpara34=line([0 0],[Anew1(2,2) 0],'color','k');
   pause(1)
end

set(mh,'string',mess5,'unit','normal','color','b');
pause(2)
set(mhcont,'visible','on');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');


if triang=='Y'
   %displaying message 6
   set(mh,'string',mess6,'unit','normal','color','b');
   pause(2)

   %changing colors of triangular regions
   axes(pgrf);
   set(tr1,'facecolor',bkgr);
   pause(2)
   set(tr2,'facecolor','m');
   pause(2)
   set(tr1,'edgecolor',bkgr);
   pause(2)
   set(tr2,'edgecolor','m');

else
   
   %displaying message 6
   set(mh,'string',mess6,'unit','normal','color','b');
   pause(4)
   axes(pgrf);
   set(para1,'visible','off');
   set(newvvec1,'visible','off');
   set(newvvec2,'visible','off');
   set(newuvec1,'visible','off');
   para3=patch([0 Anew1(1,1) Anew1(1,1) 0],...
               [0 0 Anew1(2,2) Anew1(2,2)],'m');  
end
pause(2)

%turning off messages
set(mhcont,'visible','on');
pause
set(mh,'color',bkgr);
set(mhcont,'visible','off');

%last set of messages
axes(messax); %changed for movie
mh1=text(0,0,'Area of the rectangle = Area of the parallelogram','unit','normal','color','r','fontsize',14,...
    'fontweight','bold');
%mh1=text(0,.4,mess7a,'unit','normal','color','r','fontsize',14,...
%    'fontweight','bold');
%mh2=text(0,0,mess7b,'unit','normal','color','r','fontsize',14,...
%    'fontweight','bold');
%set(mh,'string',mess8,'unit','normal','color','b');
pause(2)
%drawing original vectors & parallelogram in outline form
axes(pgrf);
uvec=line([0 u(1)],[0 u(2)],'color','r','linewidth',2);
vvec=line([0 v(1)],[0 v(2)],'color','b','linewidth',2);
%sizarr=10;
%uvec=arrow([0 0],[u(1) u(2)],...
%         sizarr,'BaseAngle',60,'facecolor','y','edgecolor','r','linewidth',2);
%vvec=arrow([0 0],[v(1) v(2)],...
%         sizarr,'BaseAngle',60,'facecolor','y','edgecolor','b','linewidth',2);
plot([u(1) upv(1)],[u(2) upv(2)],'-b','linewidth',2)
plot([upv(1) v(1)],[upv(2) v(2)],'-r','linewidth',2)
drawnow
pause(3)
axes(messax); %changed for movie
%mhcont1=text(0,0,contend,'units','normal','color','k','fontsize',14,...
 %       'fontweight','bold');

%THE END
hold off
return

