function S=bksubpr(A,b)                   % last updated 4/4/00
%BKSUBPR  Back substitution practice routine; a smart tutor.
%         Matrix A can be at most 5x5 and must be upper triangular.
%         Column b is the right-hand side of the system.
%         A component of the solution can be expressed
%         as a single numerical value that you calculate or
%         an expression in terms of constants or entry names of 
%         the matrix A, column b, or previously computed solution
%         entries x(4), x(3), etc.
%         ***NOTE: routine BACKSUB is required.***
%
%         Use in the form  --> bksubpr(A,b) <--
%
%By:David R. Hill, MATH Dept, Temple University
%   Philadelphia, Pa.  19122
%   Email: dhill001@temple.edu
i=sqrt(-1);j=sqrt(-1); %setting complex unit
header='          PRACTICE with BACK SUBSTITUTION';
sp=' ';
over='BKSUBPR is over.';
soln='The solution so far is:';
qs=['x(1) =                ';
    'x(2) =                ';
    'x(3) =                ';
    'x(4) =                ';
    'x(5) =                '];
v=['Solve for x(1).';'Solve for x(2).';'Solve for x(3).';
   'Solve for x(4).';'Solve for x(5).'];
vv=['x(1) = ';'x(2) = ';'x(3) = ';'x(4) = ';'x(5) = '];
m1=['Enter an expression in terms of the entries of A, b and previously';
    'computed components of the solution vector x.                     '];
m2='The last column of the matrix below is b.';
m3='n = size of A and k is the variable number.';
menu1=['    <1>  A is inconsistent, so quit.  ';
       '    <2>  A is consistent, so continue.';
       '    <0>  Quit.                        '];
menu2=['*** Sorry, that is not correct.               ';
       '   <1>  Try again.   <2>  Help.     <0>   Quit'];
resp='Enter your choice --> ';
hlp=['x(k) = (b(k) - A(k,n)*x(n) - A(k,n-1)*x(n-1) - ...)/A(k,k)      ';
     '                                                                ';
     'NOTE: the values of the solution must be written as             ';
     '         x(1) or x1, x(2) or x2, etc.                           ';
     '                                                                '];
clc,disp(header),disp(sp)
if max(size(A)) > 5
  disp('Matrix A must be at most 5x5.'),disp(over)
  return
end
if (size(A)==size(A') & all(all(A==triu(A))))
  [m,n]=size(A);a=A; %A or a can be used for coeff. matrix
  disp(m2),disp(sp),disp([A b]),disp(menu1)
  ch=input(resp);
  if ch==0,clc,disp(over),return,end
  while ch~=1 & ch~=2
    disp('Improper choice!  Try again.'),pause(5)
    clc,disp(header),disp(sp),disp(m2),disp(sp),disp([A b]),disp(menu1)
    ch=input(resp);
  end
  dt=abs(prod(diag(A)));
  if ch==1 & dt<100*eps
    disp(['CORRECT - ' over]),pause(5)
    return
  end
  if ch==2 & dt<100*eps
    disp('INCORRECT - System is inconsistent!'),disp(over)
    return
  end
  if ch==1 & dt>100*eps
    disp('No, the system is consistent.'),pause(2)
  end
  clc,disp('Begin BACK substitution practice.'),disp(sp)
  xt=backsub(A,b);xt=xt.'; %computes solution
  k=n;
  if n>=1,x1=xt(1);
     x1r=real(x1);x1i=imag(x1);
     if abs(x1i)<1.e-10
        stx1=num2str(x1);
     else
        if x1i<0,sgn='-';else,sgn='+';end
        stx1=[num2str(x1r) sgn num2str(abs(x1i)) 'i'];
     end
  end   %set up so xj = true value
  if n>=2,x2=xt(2);
     x2r=real(x2);x2i=imag(x2);
     if abs(x2i)<1.e-10
        stx2=num2str(x2);
     else
        if x2i<0,sgn='-';else,sgn='+';end
        stx2=[num2str(x2r) sgn num2str(abs(x2i)) 'i'];
     end
  end  
  if n>=3,x3=xt(3);
     x3r=real(x3);x3i=imag(x3);
     if abs(x3i)<1.e-10
        stx3=num2str(x3);
     else
        if x3i<0,sgn='-';else,sgn='+';end
        stx3=[num2str(x3r) sgn num2str(abs(x3i)) 'i'];
     end
  end  
  if n>=4,x4=xt(4);
     x4r=real(x4);x4i=imag(x4);
     if abs(x4i)<1.e-10
        stx4=num2str(x4);
     else
        if x4i<0,sgn='-';else,sgn='+';end
        stx4=[num2str(x4r) sgn num2str(abs(x3i)) 'i'];
     end
  end  
if n==5,x5=xt(5);
     x5r=real(x5);x5i=imag(x5);
     if abs(x5i)<1.e-10
        stx5=num2str(x5);
     else
        if x5i<0,sgn='-';else,sgn='+';end
        stx5=[num2str(x5r) sgn num2str(abs(x3i)) 'i'];
     end
  end  

%  if n>=2,x2=xt(2);stx2=num2str(x2);end
% if n>=3,x3=xt(3);stx3=num2str(x3);end
%  if n>=4,x4=xt(4);stx4=num2str(x4);end
%  if n==5,x5=xt(5);stx5=num2str(x5);end

  for ii=1:n  %constructing solution display
     if ii==1,string=stx1;end
     if ii==2,string=stx2;end
     if ii==3,string=stx3;end
     if ii==4,string=stx4;end
     if ii==5,string=stx5;end
     for jj=1:length(string),qs(ii,7+jj)=string(jj);end
   end
  while 1
    while k>=1
     xk=[];
     while isempty(xk)
      if k~=n,clc,disp(header),disp(sp),end
      disp(v(k,:)),disp(sp),disp(m1),disp(sp)
      if k~=n,disp(soln),disp(sp),st=[];
         for jj=n:-1:k+1,st=[st qs(jj,:)];end,disp(st)
      end
      disp(sp),disp('The system is:'),disp(sp),disp([A b])
      xk=input(vv(k,:));
     end
      x(k)=xk;
      if abs(xk-xt(k))>100*eps
        disp(menu2),ch=input(resp);
        if ch==0,clc,disp(over),return,end
        while ch==2
          disp(m3)
          disp(['Here n = ' num2str(n) '  and  k = ' num2str(k) '.'])
          disp(hlp),disp('Press enter to continue.'),pause
          ch=0;
        end
        break
      end 
      disp('CORRECT.'),disp(soln),disp(sp),st=[];
         for jj=n:-1:k,st=[st qs(jj,:)];end,disp(st),disp(sp),pause(4)
      k=k-1;
    end
    if k<1,break,end
  end
  clc,disp('The solution of system Ax = b by back substitution is:'),x=x.'
  S=x;  %returning the solution
else
  disp('Matrix A is either not square or not upper triangular.')
  disp(over)
end

