function chaosgame %previous update 9/16/98  last update 6/23/2015
%CHAOS GAME IFS     Iterated Function System to be entered by the user.
%             A picture is generated which approximates the attractor
%             of the IFS.
%
%             Use in the form  ==> chaosgame  <==
%             
%             When requested enter a starting vector for the iterations
%             with x and y coordinates between -1 and 1.
%
%             When asked for the number of iterations to use choose
%             several thousand.
%
%             At most 5 affine transformations can be entered.
%             Probabilities can be assigned to each transformation.
%             Follow the directions that appear on the screen.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

s0=' ';

%affine transformation data
A1=zeros(2,2);b1=zeros(2,1);
A2=zeros(2,2);b2=zeros(2,1);
A3=zeros(2,2);b3=zeros(2,1);
A4=zeros(2,2);b4=zeros(2,1);
A5=zeros(2,2);b5=zeros(2,1);

%the transformations
T1='A1*v+b1';
T2='A2*v+b2';
T3='A3*v+b3';
T4='A4*v+b4';
T5='A5*v+b5';

validtnum='N';
while validtnum=='N'
   clc
   disp('The CHAOS GAME.')
   disp(s0)
   disp('You can use up to 5 affine transformations for this experiment.')
   disp(s0)
   tnum=input('Enter the number you want to use ==>  ');
   tnum=fix(tnum);
   if tnum<1 | tnum>5
      disp('ERROR: Use 1 - 5 transformations; try again')
      disp('Press ENTER to continue.')
      pause
   else
      validtnum='Y';
   end
end

clc
disp(['You have chosen to use ' num2str(tnum) ' affine transformations.'])
disp('For each transformation you must enter a 2 by 2 matrix A')
disp('and a 2 by 1 vector b. Enter these in the form')
disp('[a b;c d] and [e f] respectively. Naturally the letters a - f')
disp('are replaced by particular numerical values.')
disp(s0)

for jj=1:tnum
    validdata='N';
    while validdata=='N'
      disp(s0);
      disp(['Enter affine transformation # ' num2str(jj) ' T(v) = Av + b.'])
      A=input('Enter the matrix in the form [a b;c d]  ==>');
      b=input('Enter the vector in the form [e f]      ==>');
      [m,n]=size(A);
      goodA='N';
      if m~=n | n~=2
         disp('ERROR: Matrix must be 2 by 2.')
         disp('Press ENTER to continue.')
         pause
      else
         goodA='Y';
      end
      b=b(:);[m,n]=size(b);
      goodb='N';
      if m~=2 | n~=1
         disp('ERROR: vector must have 2 entries.')
         disp('Press ENTER to continue.')
         pause
      else
         goodb='Y';
      end
      if goodA=='Y' & goodb=='Y'
         validdata='Y';
         if jj==1,A1=A;b1=b;end
         if jj==2,A2=A;b2=b;end
         if jj==3,A3=A;b3=b;end
         if jj==4,A4=A;b4=b;end
         if jj==5,A5=A;b5=b;end
      else
         disp('Renter this transformation; PRESS ENTER.')
         pause
      end
   end
end

validch='N';
while validch=='N'
   clc
   disp(['Do you want to assign equal probabilities to your ' num2str(tnum) ' transformations?'])
   disp(s0)
   disp(['Enter 1 for YES.';'                ';'Enter 0 for NO. '])
   ch=input('                   Your choice is   ==> ');
   if ch==0 | ch==1
      validch='Y';
   else
      disp('ERROR: Enter 1 or 0.')
      disp('Press ENTER to continue.')
      pause
   end
end

if ch==1 & tnum==1,p=[1 0 0 0 0];end
if ch==1 & tnum==2,p=[.5 1 0 0 0];end
if ch==1 & tnum==3,p=[1/3 2/3 1 0 0];end
if ch==1 & tnum==4,p=[1/4 2/4 3/4 1 0];end
if ch==1 & tnum==5,p=[1/5 2/5 3/5 4/5 1];end

if ch==0
   validprob='N';
   while validprob=='N'
      clc
      disp(['Enter a vector with ' num2str(tnum) ' values that are'])
      disp('the probabilities for the affine transformations.')
      disp('Each entry must be greater than or equal to zero and their sum must be 1.')
      yourp=input('Probabilities  [p1 p2... ] etc ==> ');
      yourp=yourp(:)';
      lnp=length(yourp);
      sump=sum(yourp);
      if any(yourp<0)==1 | lnp>tnum | sump>1
         disp('ERROR: Probabilities not valid.')
         disp('Press ENTER to continue.')
         pause
      else
         validprob='Y';
         p=[yourp zeros(1,5)];
         p=p(1:5);
         %computing intverval ends
         for jj=2:length(p)
             p(jj)=p(jj-1)+p(jj);
         end
      end
   end
end

%GET starting data & number of iterations
validinput='N';
while validinput=='N'
   clc
   disp('Enter a starting point for the iteration system.')
   disp(s0)
   v=input('Enter a vector in the form  [a  b]  ==> ');
   v=v(:);
   [m,n]=size(v);
   if m~=2 | n~=1
      disp('ERROR: Input vector v must be 2 by 1.')
      disp('PRESS ENTER to try again.')
      pause
   else
      validinput='Y';
   end
end   
validinput='N';
while validinput=='N'
   disp(s0),disp(s0)
   k=input('Enter the number of iterations to use:  ==>');
   disp(s0)
   k=fix(k);
   if k<0 | k<1000
      disp('Your value of k was negative or < 1000.')
      disp('Number of iterations set to 1000.')  
      k=1000;
   end
   validinput='Y';
end

%attempt to determine the size of graphics box 
%by computing the first 200 iterates and checking sizes

scanv=[v];
for j = 1:200
    val=rand;
    if val<=p(1)
       v=eval(T1);
    end
    if val>p(1) & val<=p(2) & tnum>=2
       v=eval(T2);
    end
    if val>p(2) & val<=p(3) & tnum>=3
       v=eval(T3);
    end
    if val>p(3) & val<=p(4) & tnum>=4
       v=eval(T4);
    end
    if val>p(4) & val<=p(5) & tnum>=5
       v=eval(T5);
    end
    scanv=[scanv v];
end
scanv=scanv(:,30:200); %ignoring first 30 iterates
xmax=max(scanv(1,:))+.5;
xmin=min(scanv(1,:))-.5;
ymax=max(scanv(2,:))+.5;
ymin=min(scanv(2,:))-.5;


ax=[xmin xmax ymin ymax];
figure
axis(ax);axis(axis);axis('square');hold on
title('The CHAOS GAME')
for j = 1:k
    val=rand;
    if val<=p(1)
       v=eval(T1);
    end
    if val>p(1) & val<=p(2) & tnum>=2
       v=eval(T2);
    end
    if val>p(2) & val<=p(3) & tnum>=3
       v=eval(T3);
    end
    if val>p(3) & val<=p(4) & tnum>=4
       v=eval(T4);
    end
    if val>p(4) & val<=p(5) & tnum>=5
       v=eval(T5);
    end
    plot(v(1),v(2),'k.','markersize',4)
    drawnow
end
xlabel('Routine is over. Press ENTER.')
