function data=compinv                       %last updated 11/15/97
%COMPINV   Comparing the flop counts for rref and inv
%          using Hilbert matrices of sizes 3 through 10.
%          Both tabluar and graphical displays are shown.
%
%          Use in the form:   ===>  compinv  <===
%                        or   ===>  data = compinv  <===
%
%          In the latter form data is an 8 by matrix with the
%          matrix size in column 1, the flops for rref in column 2,
%          and the flops for inv in column 3. 
%
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%
%STRINGS
header='COMP(uting) INV(erses); a comparison.';
s0=' ';
cont='Press Enter to continue.';


%GRAPHICS
hfig=figure('units','normal','position',[0 0 1 1],'color','white');
axis('off')

%vanity
vanbox=subplot('position',[.85 .02 .1 .06]);axis('off');
text(0,0,'by D.R.Hill','color','black','fontsize',10,...
     'fontweight','bold','fontangle','oblique','erasemode','none')

%
%TITLE
titlebox=subplot('position',[.05 .95 .5 .08]);axis('off');
titext=text(0,0,header,'color','m',...
            'fontsize',20,'fontweight','bold',...
            'erasemode','none');

%Table of data
databox=subplot('position',[.01 .25 .3 .6]);
axis('off');
datatex1=text(0,.95,'Matrix','color','k',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
datatex2=text(0,.9,'size','color','k',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
datatex3=text(.3,.95,'RREF','color','b',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
datatex4=text(.3,.9,'flops','color','b',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
datatex5=text(.6,.95,'INV','color','r',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
datatex6=text(.6,.9,'flops','color','r',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
hgt=[.80:-.1:.1];


grbox=axes('position',[.4 .1 .55 .55]);
rval=[3 10 0 10000];
axis(rval);axis(axis);
hold on;
%plot([rval(1) rval(2)],[0 0],'-k',[0 0],[rval(3),rval(4)],'-k',...
%     'erasemode','none'),drawnow
xlabel('Matrix size.','fontweight','bold','erasemode','none')
title('Blue = flops for RREF     Red = flops for INV','fontweight','bold',...
      'erasemode','none')
icnt=[];rcnt=[];
for k=3:10
   flops(0);
   A=hilb(k);   
   inv(A);
   icnt=[icnt flops];
   flops(0);
   rref([A eye(size(A))]);
   rcnt=[rcnt flops];
   axes(grbox)
   plot(k,icnt(k-2),'*r','erasemode','none')
   plot(k,rcnt(k-2),'ob','erasemode','none')
   drawnow
   axes(databox)
   text(0,hgt(k-2),num2str(k),'color','k',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
   text(.3,hgt(k-2),num2str(rcnt(k-2)),'color','b',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
   text(.6,hgt(k-2),num2str(icnt(k-2)),'color','r',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
   drawnow
   pause(2)
end
axes(grbox)
k=[3:10];
plot(k,icnt,'*-r','linewidth',2,'erasemode','none')
plot(k,rcnt,'o-b','linewidth',2,'erasemode','none')

pause(3)
%QUITbox
quitbox=axes('position',[.1,.05,.5,.06]);
axis('off')
qitext=text(0,0,cont,'color','k',...
            'fontsize',12,'fontweight','bold',...
            'erasemode','none');
data=[k' rcnt' icnt'];
clc,disp('COMPINV is over!')

