function convex                   %last updated 4/4/00
%CONVEX  Generates a graphical display of convex linear combinations.
%        A convex linear combination of vectors u and v has the form  
%                                                                 
%             t*u + (1 - t)*v   where t is in [0,1].             
%                                                                 
%         For various choices of sets of values for t in [0,1] we show 
%         graphically the formation of the linear combination and its  
%         result. For a small set of t's you can step through the     
%         generation process. Demonstrations can be selected or you    
%         can enter your own data for the vectors and the values of t. 
%
%         Use in the form -->  convex  <--
%
%         This routine calls routine convex1 which does the graphics.
%
%          Requires MATLAB 5.0 or higher.
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu
 
%STRINGS
s0=' ';
s1=['A convex linear combination of vectors u and v has the form  ';
    '                                                             ';
    '          t*u + (1 - t)*v   where t is in [0,1].             ';
    '                                                             ';
    'For various choices of sets of values for t in [0,1] we show ';
    'graphically the formation of the linear combination and its  ';
    'result. For a small set of t''s you can step through the      ';
    'generation process. Demonstrations can be selected or you    ';
    'can enter your own data for the vectors and the values of t. '];
s2='Enter vector u  ==>  ';
s3='Enter vector v  ==>  ';
s4=['           << OPTIONS >>                     ';
    '                                             ';
    '1. Use values of t = 0, .1, .2, ..., 1       ';
    '                                             ';
    '2. Use values of t = 0, .05, .1, .15, ..., 1 ';
    '                                             ';
    '3. Use values of t from 0 to 1 with a        ';
    '   spacing of 0.01 .                         ';
    '                                             ';
    '4. Enter your own choices for t.             ';
    '                                             ';
    '0. QUIT!                                     ']; 
s5='   Enter your choice  ==>  ';      
s6='Routine CONVEX is over!';
s7='Invalid choice; TRY AGAIN!';
s8='Press ENTER to continue.';
s9=['           << OPTIONS >>                    ';
    '                                            ';
    '1. Use vectors u = [3 5] and v = [7 2].     ';
    '                                            ';
    '2. Use vectors u = [-4 -7] and v = [-8 2].  ';
    '                                            ';
    '3. Enter your pair of vectors u and v.      ';
    '                                            ';
    '0. QUIT!                                    ']; 
header='        Demonstration of CONVEX Linear Combinations in 2-space.';

sig='N';
while sig=='N'
   clc
   disp(s0),disp(header)
   disp(s0),disp(s1),disp(s0),disp(s0),disp(s8),pause
   disp(s0),disp(s9)
   k=input(s5);
   if k==3
      disp(s0),u=input(s2);
      disp(s0),v=input(s3);
      if length(u)~=2 | length(v)~=2
         disp('Vectors must be in 2-space; try again.'),disp(s8),pause
      else
         sig='Y';
      end
   end
   if k==1,u=[3 5];v=[7 2];sig='Y';end  
   if k==2,u=[-4 -7];v=[-8 2];sig='Y';end 
   if k==0,clc,disp(s6),return,end
   if k~=0 & k~=1 & k~=2 & k~=3
      disp(s0),disp(s7),disp(s0),disp(s8),pause 
   end  
end

sig='N';
while sig=='N'
   clc
   disp(s0),disp(header)
   disp(s0),disp(s4),disp(s0),disp(s0)
   k=input(s5);
   if k==0,clc,disp(s6),return,end
   if k==1,s=0:.1:1;sig='Y';end
   if k==2,s=0:.05:1;sig='Y';end
   if k==3,s=0:.01:1;sig='Y';end
   if k==4
      s=input('Enter a set of values for t;  t = ');sig='Y';
   end   %NOTE: no range checking to ensure convex; this is deliberate.
   if k~=0 & k~=1 & k~=2 & k~=3 & k~=4
      disp(s0),disp(s7),disp(s0),disp(s8),pause 
   end 
end
convex1(u,v,s) 