function convex1(x1,x2,s) %previous update 4/4/00  last update 6/23/2015
%CONVEX1  Generates graphics for convex linear combination 
%         of two vectors in 2-space.
%
%         Use in the form -->  convex1(u,v,t)  <--
%
%      where u and v are vectors in 2-space and t is a set of values
%      in [0,1] for the convex linear combinations. If t has less than
%      21 points then you can step through each linear combination
%      and appropriate information is displayed. If t has more than 21
%      points then the linear combinations are performed automatically.
%      For more than 250 points a fill command is used.
%      Values of t outside the range [0,1] can also be used for various
%      views. This routine can be accessed by routine convex which 
%      provides a frontend.
%
%          Requires MATLAB 5.0 or higher.
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu
 

%NOTES:  vector x1 will be labeled u
%        vector x2 will be labeled v
s=sort(s);
k=length(s);
convsw='N'; %Switch to indicate convex lin combos
mins=min(s);
maxs=max(s);
if mins >=0 & mins <=1 & maxs <=1 & maxs>=0 & k < 21
   convsw='Y';
   if mins~=0,s=[0 s];end %making sure we get the ends
   if maxs~=1,s=[s 1];end
end
k=length(s);
z=[];
for j=1:k
zz=s(j)*x1+(1-s(j))*x2;
zz=zz(:);
z=[z zz];
end
xmin=min(z(1,:));xmax=max(z(1,:));
ymin=min(z(2,:));ymax=max(z(2,:));
%COLOR settings
bkgr='white'; %background color

%Setting figure to full screen
hfig=figure('units','normal','position',[0 0 1 1],'color',bkgr);

%data window
dataw=subplot('position',[0 0 .25 1]);
axis([0 1 0 1]);axis(axis);hold on,axis('off')

%axis for showing header
axtitle= subplot('position',[.3 .95 .3 .1]);
axis([0 1 0 1]);axis(axis);hold on
axis('off');
head=text(0,0,'CONVEX Linear Combinations','color','black',...
'fontweight','bold','fontsize',22);

%axis for showing vanity
axvan= subplot('position',[.85 .1 .09 .05]);
axis([0 1 0 1]);axis(axis);hold on
axis('off');
text(0,0,'by D.R.Hill','color','black','fontsize',14,...
'fontweight','bold','fontangle','oblique')

%axis for vectors
axvec= subplot('position',[.3 .85 .15 .1]);
axis([0 1 0 1]);axis(axis);hold on
axis('off');
vectoru=['u = [' num2str(x1(1)) ' , ' num2str(x1(2)) ']'];
vectorv=['v = [' num2str(x2(1)) ' , ' num2str(x2(2)) ']'];   
text(0,.5,vectoru,'color','red','fontsize',18,...
'fontweight','bold')
text(0,0,vectorv,'color','blue','fontsize',18,...
'fontweight','bold')

%axis for convex lin combos
axconv= subplot('position',[.3 .75 .7 .1]);
axis([0 1 0 1]);axis(axis);hold on
axis('off');
if convsw=='Y'
   vecuv=['(' num2str(s(1)) ') * u + (' num2str(1-s(1)) ') * v'];
   dispuv=text(0,0,vecuv,'color','magenta','fontsize',18,...
          'fontweight','bold');
end

%graph subplot
congr=subplot('position',[.3 .2 .6 .5]);
axis([xmin xmax ymin ymax])
axis(axis)
plot([xmin xmin], [ymin ymax],'w.')
hold on
plot([0 x1(1)],[0 x1(2)],'-r',[0 x2(1)],[0 x2(2)],'-b',...
     'linewidth',2)
text(x1(1)/2,x1(2)/2,'u','color','red','fontweight','bold',...
     'fontsize',18)
text(x2(1)/2,x2(2)/2,'v','color','blue','fontweight','bold',...
     'fontsize',18)
%START of action
if k>250 & convsw=='Y'
   fill([0 x1(1) x2(1) 0],[0 x1(2) x2(2) 0],'k')
else
   
for j=1:k
   if k<=21
      if j==1
         subplot(dataw)
         text(.1,.98,'Coeff.','fontsize',14,'color','red','fontweight','bold')
         text(.1,.94,'of u','fontsize',14,'color','red','fontweight','bold')
         text(.5,.98,'Coeff.','fontsize',14,'color','blue','fontweight','bold')
         text(.5,.94,'of v','fontsize',14,'color','blue','fontweight','bold')
      end
      subplot(dataw)
      text(.1,.90-(j-1)*.035,num2str(s(j),4),'fontsize',14,'fontweight','bold')
      text(.5,.90-(j-1)*.035,num2str(1-s(j),4),'fontsize',14,'fontweight','bold')
      subplot(axconv)
      if exist('dispuv')==1,delete(dispuv);end
      result=s(j)*x1+(1-s(j))*x2;
      vecuv=['(' num2str(s(j)) ') * u + (' num2str(1-s(j)) ') * v'];
      vecuv=[vecuv ' = [' num2str(result(1)) ' , ' num2str(result(2)) ']'];
      dispuv=text(0,0,vecuv,'color','magenta','fontsize',18,...
             'fontweight','bold');
      
   end
   subplot(congr)
   u1=plot([0 s(j)*x1(1)],[0 s(j)*x1(2)],'-m','linewidth',2);
   uv1=plot([s(j)*x1(1) z(1,j)],[s(j)*x1(2) z(2,j)],'-m');
   v1=plot([0 (1-s(j))*x2(1)],[0 (1-s(j))*x2(2)],'-m','linewidth',2);
   uv2=plot([(1-s(j))*x2(1) z(1,j)],[(1-s(j))*x2(2) z(2,j)],'-m');
   diaguv=plot([0 z(1,j)],[0 z(2,j)],'-k');
   plot([0 z(1,j)],[0 z(2,j)],'*m')
   if k<=21
      xlab=xlabel('Press ENTER for next step.','fontsize',14,'fontweight','bold');
      pause,delete(xlab),pause(1)
   end
   delete(u1);%plot([0 s(j)*x1(1)],[0 s(j)*x1(2)],'-r')
   delete(uv1);%plot([s(j)*x1(1) z(1,j)],[s(j)*x1(2) z(2,j)],'-w')
   delete(v1);%plot([0 (1-s(j))*x2(1)],[0 (1-s(j))*x2(2)],'-b')
   delete(uv2);%plot([(1-s(j))*x2(1) z(1,j)],[(1-s(j))*x2(2) z(2,j)],'-w')
   %if k<=21     %omitted this 4/4/00 to leave diagonals visible
   %   delete(diaguv);
   %end
   plot([0 x1(1)],[0 x1(2)],'-r',[0 x2(1)],[0 x2(2)],'-b',...
     'linewidth',2)
end
end
%axis for done
axdone= subplot('position',[.45 .1 .15 .05]);
axis([0 1 0 1]);axis(axis);hold on
axis('off');
text(0,0,'Press ENTER to Continue.','color','black','fontsize',14,...
'fontweight','bold')

hold off