function finalmatrix = detpr(A)                     %last updated 3/19/00
%DETPR   Perform row reduction on matrix A by explicitly choosing
%        row operations to use in order to compute its determinant.
%        After each row operation you will be asked to determine
%        the change of value in the determinant that results from
%        the row operation. At most 6 by 6 matrices permitted.
%
%        HELPFUL HINT: For row operations of the form 
%
%               k*Row(i) + Row(j)    or    k*Row(i)
%
%        the multiplier k can be expressed in terms of the entries
%        of the matrix A which is operated on. For example,
%
%          -A(2,1)/A(1,1) * Row(i) + Row(j)   or   1/A(2,3) * Row(2)
%
%        This method of forming the multipliers uses the exact values
%        of the entries since only a decimal approximation may appear
%        in the displays.
%
%        A row operation can be "undone", but this feature cannot 
%        be used in succession.
%
%        Use in the form ===>  detpr(A)  <===
%
%  By: David R. Hill, Mathematics Dept., Temple Univ.
%      Philadelphia, PA. 19122    Email: dhill001@temple.edu


%Checking for square matrix
[m,n]=size(A);
if m~=n,clc,disp('ERROR: Matrix must be square.'),return,end
if m>6,clc,disp('ERROR: Matrix can be at most 6 by 6.'),return,end

%Initializing
rsig='F'; %Setting switch for rational display off initially.
oldA=A;
firsttime='Y'; %signal for first valid row op
prevmult=1;  %value of previous multiplier
detoforig=det(A); %value of det of original matrix

%Determining if complex
imck=sum(sum(abs(imag(A)))); %checking if any complex entries
if imck<1.e-10,imck=0;else,imck=1;end %setting switch for complex
%if imck =1 then rational display option not available
%

%Setting tolerance
myeps=1e-13; %my tolerance for zero in rational display
%I found that 1e-14 was too small in a number of cases.
%Changed 3/19/00.

%
%Set up strings to be used as messages.
s0='     ';
s1='Enter first row number.  ';
s2='Enter second row number.  ';
s3='Enter scalar multiplier.  ';
s4='Enter nonzero scalar multiplier.  ';
s5='Enter row number.  ';
s6='Enter number of row that changes.  ';
s7='Last row operation "undone". ';
s8='               ***** "DETERMINANT" of a Matrix by Row Reduction *****';
s9='         The current matrix is:';
s10='     ENTER your choice ===> ';
s11='Press  ENTER  to continue';
s12='*****  ==>  DETPR is over. Your final matrix is:';
s13='** Improper row number! **';
s14='Interchange Complete: ';
s15='Row Multiplication Complete: ';
s16='Replacement by Linear Combination Complete: ';
s17='Enter your computed value of det(original matrix): ==>';
s18='Your value for det(original matrix) is NOT correct.';
arrow=[setstr(60) setstr(45) setstr(45) setstr(62)];
menureal=...
['            OPTIONS                       ';
 ' <1>  Row(i) <==> Row(j)                  ';
 ' <2>  k*Row(i)    (k not zero)            ';
 ' <3>  k*Row(i) + Row(j)  ==>  Row(j)      ';
 ' <4>  Turn on rational display.           ';
 ' <5>  Turn off rational display.          ';
 ' <6>  Check value of det(original matrix).';
 '<-1>  "Undo" the last row operation.      ';
 ' <0>  Quit DETPR!                         '];

oldreal=...
['            OPTIONS                                                      ';
 ' <1>  Row(i) <==> Row(j)                           <4>  Turn on rational ';
 ' <2>  k*Row(i)    (k not zero)                          display.         ';
 ' <3>  k*Row(i) + Row(j)  ==>  Row(j)                                     ';
 ' <6>  Check value of det(original matrix).         <5>  Turn off rational';
 '<-1>  "Undo" the last row operation.                    display.         ';
 ' <0>  Quit DETPR!                                                        '];

menuimag=...
['            OPTIONS                          ';
 ' <1>  Row(i) <==> Row(j)                     ';
 ' <2>  k*Row(i)    (k not zero)               ';
 ' <3>  k*Row(i) + Row(j)  ==>  Row(j)         ';
 ' <6>  Check value of det(original matrix).   ';
 '<-1>  "Undo" the last row operation.         ';
 ' <0>  Quit DETPR!                            '];

mess=s8;
i=sqrt(-1);j=i; %setting complex units

%
imck=sum(sum(abs(imag(A)))); %checking if any complex entries
if imck<1.e-10,imck=0;else,imck=1;end %setting switch for complex
%if imck =1 then rational dislay option not available
if imck==0,menu=oldreal;else,menu=menuimag;end  %setting up menu
                                                     %for real & complex
                                                     %matrices

%SHOWING HELP & the HINT
clc,disp(s8),disp(s0)
disp('Read the HELPFUL HINT that is given in the following description.')
disp(s0),disp(s11),pause
clc,help detpr,disp(s11),pause

%MAIN LOOP
while 1
  clc,clc,format compact
  disp(mess)
  disp(s9),disp(s0)
  a=A; %to prevent case mismatch in multiplier choice
  if imck==0 & rsig=='T'
     format rational
     A
     format,format compact
  else
     A
  end
  if firsttime=='N'
     disp(s0)
     disp(['det(ORIGINAL MATRIX) = ',num2str(prevmult),' * det(CURRENT "A" MATRIX)']);
  end
  disp(s0),disp(menu)
  ch=input(s10);
  if isempty(ch),ch=999;end %trapping empty input
  if ch==-1
    A=oldA;prevmult=oldmult;
    mess=s7;
  end
  if ch==0
    clc
    disp(s12)
    disp(s0)
    if imck==0 & rsig=='T'
       format rational
       disp(A)
       format
    else
       disp(A)
    end
    finalmatrix=A;
    disp(s0)
    disp(['det(ORIGINAL MATRIX) = ',num2str(prevmult),' * det(FINAL MATRIX)']);
    format loose
    return
  end
  if ch==4 & imck==0, rsig='T';end
  if ch==5 & imck==0, rsig='F';end
  if ch==6
     disp(s0),compval=input(s17);
     if abs(compval-detoforig)<myeps
        disp(s0),disp(['CORRECT:  det(original matrix) = ' num2str(compval)])
     else
        disp(s0),disp(s18)
     end
     disp(s11)
     pause
  end
  if ch==1
    sig='Y';
    jj=input(s1);
    k=input(s2);
    aj=abs(fix(jj));ak=abs(fix(k));
    if jj~=aj | jj>m | k~=ak | k>m | jj==0 | k==0 | (jj==k)
      disp(s13)
      if (jj==k),disp('Row numbers must be different.'),end
                 %ensuring different rows on interchange
      disp(s11)
      pause
      sig='N';
      mess=s0;
    end
    if sig=='Y'
      oldA=A;
      temp=A(jj,:);
      A(jj,:)=A(k,:);
      A(k,:)=temp;
      mess= [s14 ' Row ' int2str(jj) ' ' arrow ' Row ' int2str(k) ];
    end
  end
  if ch==2
    sig='Y';
    k=input(s3);kval=k; %for use in det equation
    while (k==0)
      k=input(s4);
    end
    jj=input(s5);
    aj=abs(fix(jj));
    if jj~=aj | jj>m | jj==0
      disp(s13)    
      disp(s11)
      pause
      sig='N';
      mess=s0;
    end
    if sig=='Y'
      oldA=A;
      A(jj,:)=k*A(jj,:);
      %determine if multiplier is complex
      if abs(imag(k))< 1.e-10
         mess=[s15 num2str(k) ' * Row ' int2str(jj) ]; %k is real
      else
         kr=real(k);ki=imag(k); %k is truly complex
         if ki<0, sg=' - ', else, sg=' + ';end
      mess=[s15 num2str(kr) sg num2str(abs(ki)) 'i' ' * Row ' int2str(jj)];
      end
    end
  end
  if ch==3
    sig='Y';
    t=input(s3);kval=t;
    k=input(s1);
    jj=input(s6);
    aj=abs(fix(jj));ak=abs(fix(k));
    if jj~=aj | jj>m | k~=ak | k>m | k==0 | jj==0
      disp(s13)
      disp(s11)
      pause
      sig='N';
      mess=s0;
    end
    if sig=='Y'
      oldA=A;
      A(jj,:)=t*A(k,:)+A(jj,:);
      for ii=1:n,if abs(A(jj,ii))<=myeps,A(jj,ii)=0;end,end
      %determine if multiplier t is complex
      if abs(imag(t))< 1.e-10
         mess=[s16 num2str(t) ' * Row ' int2str(k) ' + Row '];
         mess=[mess int2str(jj)]; %multiplier t is real
      else
         tr=real(t);ti=imag(t); %t is truly complex
         if ti<0, sg=' - ', else, sg=' + ';end
         mess=[s16 num2str(tr) sg num2str(abs(ti)) 'i'];
         mess=[mess  ' * Row ' int2str(k) ' + Row '];
         mess=[mess int2str(jj)];
      end
    end
  end

%Check valid code 
%
  validch='N';
  if imck==0 & (ch==1 | ch==2 |ch==3 | ch==4 | ch==5 | ch==6 |ch==-1)
     validch='Y';
  end
  if imck==1 & (ch==1 | ch==2 |ch==3 |ch==6| ch==-1)
     validch='Y';
  end
  
  if validch=='N'
     disp('Improper choice; try again.')
     disp(s11),pause
  else
     if (ch==1 | ch==2 |ch==3 ),dodet='Y';else,dodet='N';end
     if (ch==1 & sig=='N'),dodet='N';end  %code to skip display if try
                                         %to interchange a row with itself
     if dodet=='Y'                         
        validk='N';
        while validk=='N'
           clc,disp(mess),
           disp('on the PREVIOUS MATRIX')
           disp(s0)
           if imck==0 & rsig=='T'
              format rational
              disp(oldA)
              format,format compact
           else
              disp(oldA)
           end
           disp(s0)
           disp('to produce NEW MATRIX')
           disp(s0)
           if imck==0 & rsig=='T'
              format rational
              disp(A)
              format,format compact
           else
              disp(A)
           end 
           if ch==2 | ch==3  
              disp(s0)
              disp('DETERMINE a value for ?? in the equation below.')
              disp(s0)
              disp('If convenient you may express it ')
              disp('in terms of the multiplier whose name is kval.')
           else
              disp('Determine an expression for ?? in the following equation.')
           end
           disp(s0)
           disp('det(PREVIOUS MATRIX) = __??__ * det(NEW MATRIX)')
           disp(s0)
           yourkval=input('Value for ?? is : ==>  ');
           if ch==3
              if yourkval==1
                 validk='Y';currmult=1;
                 disp('CORRECT; press ENTER to continue.')
                 pause
              else
                 disp('No, not a correct value for the multiplier in the determinant equation.')      
                 disp(s11),pause
              end
           end
           if ch==2
              if abs(yourkval-(1/kval))<myeps
                 validk='Y';currmult=1/kval;
                 disp('CORRECT; press ENTER to continue.')
                 pause
              else
                 disp('No, not a correct value for the multiplier in the determinant equation.')      
                 disp(s11),pause
              end
           end
           if ch==1
              if abs(yourkval-(-1))<myeps
                 validk='Y';currmult=-1;
                 disp('CORRECT; press ENTER to continue.')
                 pause
              else
                 disp('No, not a correct value for the multiplier in the determinant equation.')      
                 disp(s11),pause
              end
           end
       end %of while validk
       %Construct code for det(orig) in terms of det(new or current matrix)
       if firsttime=='Y'
          firsttime='N';,disp(s0)
          disp(['det(ORIGINAL MATRIX) = ',num2str(currmult),' * det(NEW MATRIX)'])
          disp(s0)
          disp(s11),pause,oldmult=prevmult;
          prevmult=currmult*prevmult;
       else
          disp(s0)
          messeq=['det(ORIGINAL MATRIX) = ',num2str(prevmult)];
          messeq=[messeq [' * det(PREVIOUS MATRIX) = ',num2str(prevmult)]];
          messeq=[messeq [' * ',num2str(currmult),' * det(NEW MATRIX)']];
          disp(messeq),disp(s0),disp(s11)
          pause,oldmult=prevmult;
          prevmult=currmult*prevmult;
       end



    end % of dodet
     
  end %of validch

end  %while 1
