function tab=divdiff(x,y)                  %last updated 8/9/94
%DIVDIFF  Calculate a divided difference table from data
%         contained in the vectors x and y. The top row
%         contains the coefficients for the divided difference 
%         interpolating polynomial. The independent variable
%         appears in column 1 and the dependent in column 2.
%         Other columns are the higher ordered divided
%         differences.
%         Use in the form  ===> divdiff(x,y)  <===
%
% By:  David R. Hill, MATH Dept., Temple University
%      Philadelphia, Pa. 19122    Email: dhill001@temple.edu

if nargin~=2,disp('There must be two arguments.'),return,end
[m,n]=size(x);
if m==1,x=x';end
if m~=1 & n~=1,disp('The arguments must be vectors.'),return,end
[m,n]=size(y);
if m==1,y=y';end
if m~= 1 & n~=1,disp('The arguments must be vectors.'),return,end
k=length(x);
if k~=length(y)
   disp('The vectors must be the same length.'),return
end
tab=[x y];
for j=1:k-1
    if j==1
       d=diff(tab(:,2))./diff(tab(:,1));
    else
       z=zeros(k-j,1);
       for i=1:k-j
            z(i,1)=tab(i+j,1)-tab(i,1);
       end
       d=diff(tab(1:k-j+1,j+1))./z;
    end
    tab(:,j+2)=[d' zeros(j,1)']';
end
