 function dragon(p) %previous update 9/16/98  last update 6/23/2015
%dragon    Draws the DRAGON Curve at the pth step; 2^p line segments used.
%
%        Use in the form  ==>  dragon(p)  <==
%        p an integer > 1
%        
%        Adapted from Fractals, Endlessly Repeated Geometric Figures
%                by   Hans Lauwerier
%                     Princeton University Press, 1991
%                     ISBN 0-691-02445-6
%
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu


if p<=0 | fix(p)~=p
   disp('Error: Input value of p must be a positive integer.')
   return
end
number=2^p;
if p >= 10
   disp(['Warning: ' num2str(number) ' line segments will be drawn.'])
   disp('This may require a lot of time.')
   disp(' ')
   val=input('Press 0 to quit; any other key to go on.');
   if isempty(val)==1
      val=999;
   end   
   if val==0,return,end
end

%Setting up the axes
figure
ax=[-1.5,1.5,-1.5,1.5];  %this can be adjusted in needed.
axis(ax);axis(axis);axis('square');hold on

%rot45=(sqrt(2)/2)*[1 1;-1 1];
h=2^(-p/2);
A=90;            %angle
A=A*pi/180;
B=pi-A;
x=h;
y=0;
plot([0 h],[0 0],'k-')

s=0;
for n=1:2^p-1
    oldx=x;oldy=y;
    m=n;
    while mod(m,2)==0
       m=m/2;
    end
    if mod(m,4)==1
       d=1;
    else
       d=-1;
    end
    s=s+d;
    x=oldx+h*cos(s*B);
    y=oldy+h*sin(s*B);
    %z=rot45*[x y]';
    %x=z(1);y=z(2); 
    plot([oldx x],[oldy y],'k-')
    if n==1
       title(['Dragon Curve with ' num2str(number) ' line segments.']) 
    end
    drawnow
end
xlabel('Routine is over. Press ENTER.')
