function dragonifs(v,k) %previous update 4/10/00  last update 6/23/2015
%DRAGON IFS   Iterated Function System for the Dragon Curve
%             A picture is generated.
%
%             Use in the form  ==> dragonifs(v,k)  <==
%             where
%                   v = [x y] is a point to start the iteration
%                       denoted by o in the picture provided it 
%                       is close enough to the dragon figure. 
%                       Similarly the first three iterates may 
%                       appear as + signs.
%
%                   k = the number of composites to form
%                       (5000 gives a pleasing picture)
%             If no value of k is specified k = 1000 is used.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%affine transformation data
A1=[.5 .5;-.5 .5];
A2=[-.5 .5;-.5 -.5];
b2=[sqrt(2)/2 0]';

%the transformations
T1='A1*v';
T2='A2*v+b2';

v=v(:);
if nargin==1,k=1000;,end

hfig=figure('units','normal','position',[0 0 1 1],'color','white');
axis('off')

tag=subplot('position',[.4 .08 .2 .05]);
axis('off')
mess=text(.3,.1,'Routine is over. Press ENTER.','fontsize',14,'fontweight','bold');
set(mess,'visible','off')

gfr=subplot('position',[.15 .15 .9 .9]);
ax=[-1 1 -1 1];
axis(ax);axis(axis);axis('square');axis('off');hold on
plot(v(1),v(2),'ko')
text(-.5,.8,'Dragon Fractal','color','red',...
           'fontsize',16,'fontweight','bold')

drawnow

for j = 1:k
    if rand>=0.5
       v=eval(T1);
    else
       v=eval(T2);
    end
    if j>=2 & j<5
       plot(-v(1),-v(2),'k+')
    else
       plot(-v(1),-v(2),'k.','markersize',6)
    end
    %note: the negative signs are here so that the figure agrees
    %      with the dragon shape that comes out of m-file dragon 
    %        Adapted from Fractals, Endlessly Repeated Geometric Figures
    %                by   Hans Lauwerier   
    drawnow
end
subplot(tag)
set(mess,'visible','on')
 
clc,disp('dragonifs routine is over.')
disp('To delete all figures currently available type close all.')
disp('To delete only the last figure generated type close gcf.')
