function elemmat                                    %last updated 11/4/94
%ELEMMAT  A tutorial on elementary matrices.
%         Discussion, examples, and algorithms are used.
%         The following areas are covered:
%             Definition and brief discussion.
%             Constructing an elementary matrix.
%             Using an elementary matrix to perform row operations.
%             Discussion of inverses of elementary matrices.
%             Summary of properties and matrix factorization.
%
%         Use in the form  --->  elemmat  <---
%
%  By: David R. Hill, Mathematics Dept., Temple Univ.
%      Philadelphia, PA. 19122    Email: dhill001@temple.edu

%Constants used by the routine:
myeps=1.e-14;  %used in test for zero value
format compact
%Set up strings to be used as messages.
s0='     ';
s1='Enter first row number.  ';
s2='Enter second row number.  ';
s3='Enter multiplier.  ';
s4='Enter nonzero multiplier.  ';
s5='Enter row number.  ';
s6='Enter number of row that changes.  ';
s7='Last row operation "undone". ';
s8='               ***** "REDUCE" a Matrix by Row Reduction *****';
s9='         The current matrix is:';
s10='     ENTER the number of your choice ---> ';
s11='Press  ENTER  to continue';
s12='*****  -->  ELEMMAT is over.  <--  *****';
s13='** Improper row number! **';
s14='Interchange Complete.';
s15='Row Multiplication Complete.';
s16='Replacement by Linear Combination Complete.';
s17='Press ENTER to return to the main menu.';
s18='Press enter to see the next example.';
s20='Row operation ';
s21=' corresponds to elementary matrix E. ';
s22='To perform the row operation we compute the product E*A.';
s23='     Row Operations as Multiplication by Elementary Matrices';
s24='Matrix A is';
s25='and the product E*A is';
lct=' ';lcb=' ';rct=' ';rcb=' ';vl=' ';
%Set to spaces because of fint problems in windows.
%lct=setstr(218);  %left corner top
%lcb=setstr(192);  %left corner bottom
%rct=setstr(191);  %right corner top
%rcb=setstr(217);  %right corner bottom
%vl=setstr(179);   %vertical segment

title1=[blanks(30) 'ELEMENTARY MATRICES'];
title2=[blanks(15) 'LEARNING' blanks(10) 'PRACTICE' blanks(10)];
title2=[title2 'REVIEW'];
menu=['             OPTIONS                                      ';
      ' <1> Definition and brief discussion.                     ';
      ' <2> Constructing an elementary matrix.                   ';
      ' <3> Using an elementary matrix to perform row operations.';
      ' <4> Discussion of inverses of elementary matrices.       ';
      ' <5> Summary of properties and matrix factorization.      ';
      '                                                          ';
      ' <0> Quit.                                                '];
intro =...
['     This routine is an aid in learning about elementary matrices';
 '                                                                 ';
 'and experimenting with them. You will be presented with a menu of';
 '                                                                 ';
 'choices. If you are using this routine for the first time begin  ';
 '                                                                 ';
 'with number <1>. If you are reviewing ideas about elementary     ';
 '                                                                 ';
 'matrices, then choose your area of interest. For ease of         ';
 '                                                                 ';
 'presentation we use only 3 by 3 matrices.                        '];
def = ...
['                   ***** DEFINITION *****                           ';
 '                                                                    ';
 '  An elementary matrix is a matrix obtained by performing a single  ';
 '  row operation on an identity matrix.                              ';
 '                                                                    ';
 '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++';
 '                                                                    ';
 '  Discussion:                                                       ';
 '                                                                    ';
 '    There are 3 types of elementary matrices, one for each type of  ';
 '    row operation. (There are also elementary matrices corresponding';
 '    to column operations, but we do not discuss them here.)         ';
 '                                                                    ';
 '    Elementary matrices are a tool that permits us to write matrix  ';
 '    equations corresponding to row operations. For example, instead ';
 '    of saying do a row operation on matrix A to get matrix B, we can';
 '    write                                                           ';
 '              B = E*A                                               ';
 '                                                                    ';
 '    where E is the elementary matrix corresponding to the row       ';
 '    operation.                                                      '];
con1 = ...
['                   Constructing Elementary Matrices              ';
 '                                                                 ';
 '     To construct an elementary matrix we perform a single row   ';
 'operation on an identity matrix. For the 3 by 3 case we have the ';
 'following examples:                                              '];
con2 = ...
['Example 1.  The elementary matrix corresponding to row operation ';
 '            interchange rows 1 and 3 is E1.                      '];

mat1 = ...
 [['     ' lct '          ' rct];
  ['     ' vl  ' 0   0   1' vl ];
  ['E1 = ' vl  ' 0   1   0' vl ];
  ['     ' vl  ' 1   0   0' vl ];
  ['     ' lcb '          ' rcb]];

con3 = ...
['Example 2.  The elementary matrix corresponding to row operation ';
 '            5 times row 2 is E2.                                 '];
mat2 = ...
 [['     ' lct '          ' rct];
  ['     ' vl  ' 1   0   0' vl ];
  ['E2 = ' vl  ' 0   5   0' vl ];
  ['     ' vl  ' 0   0   1' vl ];
  ['     ' lcb '          ' rcb]];

con4 = ...
['Example 3.  The elementary matrix corresponding to row operation ';
 '            -4 times row 1 added to row 3 is E3.                 '];
mat3 = ...
 [['     ' lct '          ' rct];
  ['     ' vl  ' 1   0   0' vl ];
  ['E3 = ' vl  ' 0   1   0' vl ];
  ['     ' vl  '-4   0   1' vl ];
  ['     ' lcb '          ' rcb]];

use1 = ...
['                    Using Elementary Matrices                     ';
 '                                                                  ';
 'Here you can experiment constructing elementary matrices and use  ';
 'them to perform row operations.                                   '];

use2 = ...
['              OPTIONS                         ';
 '                                              ';
 ' <1> Enter a 3 by 3 matrix A of your own.     ';
 ' <2> Have MATLAB generate a 3 by 3 matrix A.  ';
 '                                              ';
 ' <0> Quit this and return to the main menu.   '];

usetitle = ...
['               Reduce Matrix A by Using Elementary Matrices          '];
use3 = ...
['                                                                     ';
 '                             OPTIONS                                 ';
 ' <1>  Interchange two rows using an elementary matrix.               ';
 ' <2>  Multiply a row by a nonzero scalar using an elementary matrix. ';
 ' <3>  Replace a row by linear combination of itself with another row.';
 '      using an elementary matrix.                                    ';
 '<-1>  "Undo" previous row operation.                                 ';
 ' <0>  Quit and return to the main menu.                              '];

use4 = ...
['           Arithmetic Display Mode Choice';
 '                                         ';
 '<1> Rational Display.                    ';
 '<2> Decimal Display.                     '];

inv1=...
['                   Inverses of Elementary Matrices                      ';
 '                                                                        ';
 '    For each row operation there is a corresponding elementary matrix.  ';
 '                                                                        ';
 'Each row operation can be "undone" or reversed by a row operation of    ';
 '                                                                        ';
 'the same type. This suggests that every elementary matrix is invertible ';
 '                                                                        ';
 'or nonsingular. In what follows we discuss how to construct the inverse ';
 '                                                                        ';
 'of each type of elementary matrix.                                      '];

invmenu=...
['                             OPTIONS                                   ';
 '                                                                       ';
 '<1>  Inverse of elementary matrix corresponding to a row interchange.  ';
 '                                                                       ';
 '<2>  Inverse of elementary matrix corresponding to multiplying a row   ';
 '     by a nonzero scalar.                                              ';
 '                                                                       ';
 '<3>  Inverse of elementary matrix corresponding to adding a multiple   ';
 '     of one row to another.                                            ';
 '                                                                       ';
 '<0>  Quit this and return to the main menu.                            '];

inv2=...
['                        Inverses and Row Interchanges                 ';
 '______________________________________________________________________';
 '                                                                      ';
 '     The row operation                                                ';
 '                         interchange rows i and j                     ';
 '                                                                      ';
 'is reversed by the operation                                          ';
 '                                                                      ';
 '                         interchange rows i and j                     ';
 '                                                                      ';
 'Thus the corresponding elementary matrix E1 is its own inverse.       ';
 '                                                                      ';
 '                         inverse of E1 = E1                           ';
 '                                                                      ';
 'This is the simplest case for elementary matrices.                    ';
 '______________________________________________________________________'];

inv3a=...
['                        Inverses and Row Multiples                      ';
 '________________________________________________________________________';
 '                                                                        ';
 '     The row operation                                                  ';
 '                         multiply row i by scalar k                     ';
 '                                                                        ';
 'is reversed by the operation                                            ';
 '                                                                        ';
 '                         multiply row i by scalar 1/k                   ';
 '                                                                        ';
 'We illustrate the corresponding elementary matrix situation by example. ';
 '                                                                        ';
 '          5*Row 2 corresponds to elementary matrix E2                   ';
 '        1/5*Row 2 corresponds to elementary matrix inverse of E2        ';
 '                                                                        '];

inv3b=...
[ ['     ' lct '          ' rct '             ' lct '          ' rct ];
  ['     ' vl  ' 1   0   0' vl  '             ' vl  ' 1   0   0' vl  ];
  ['E2 = ' vl  ' 0   5   0' vl  '   inv(E2) = ' vl  ' 0 1/5   0' vl  ];
  ['     ' vl  ' 0   0   1' vl  '             ' vl  ' 0   0   1' vl  ];
  ['     ' lcb '          ' rcb '             ' lcb '          ' rcb ]];

inv4a=...
['                        Inverses and Row Combinations                   ';
 '________________________________________________________________________';
 '                                                                        ';
 '     The row operation                                                  ';
 '                         k*Row i + Row j                                ';
 '                                                                        ';
 'is reversed by the operation                                            ';
 '                                                                        ';
 '                         -k*Row i + Row j                               ';
 '                                                                        ';
 'We illustrate the corresponding elementary matrix situation by example. ';
 '                                                                        ';
 '      3*Row 1 + Row 2 corresponds to elementary matrix E3               ';
 '     -3*Row 1 + Row 2 corresponds to elementary matrix inverse of E3    ';
 '                                                                        '];

inv4b=...
[ ['     ' lct '          ' rct '             ' lct '          ' rct ];
  ['     ' vl  ' 1   0   0' vl  '             ' vl  ' 1   0   0' vl  ];
  ['E3 = ' vl  ' 3   1   0' vl  '   inv(E3) = ' vl  '-3   1   0' vl  ];
  ['     ' vl  ' 0   0   1' vl  '             ' vl  ' 0   0   1' vl  ];
  ['     ' lcb '          ' rcb '             ' lcb '          ' rcb ]];

obtitle=...
['           Facts and Observations about Elementary Matrices         ';
 '____________________________________________________________________';
 '                                                                    '];

ob1=...
['1. Elementary matrices are a way of performing row operations by     ';
 '   a matrix multiply.                                                ';
 '_____________________________________________________________________';
 '2. If A and B are row equivalent then we can produce matrix B from   ';
 '   matrix A by a sequence of row operations. In terms of elementary  ';
 '   matrices this implies that there exists a sequence of elementary  ';
 '   matrices E1, E2, ..., Ek corresponding to the row operations so   ';
 '   that                                                              ';
 '                   Ek * ... * E2 * E1 * A = B.                       ';
 '                                                                     ';
 '   Thus we have a matrix equation relating row equivalent matrices.  ';
 '_____________________________________________________________________'];

ob2=...
['3. Every elementary matrix is nonsingular. If we let                   ';
 '                                                                       ';
 '                    W = Ek * ... * E2 * E1                             ';
 '                                                                       ';
 '   then W is nonsingular (it is a product of nonsingular matrices).    ';
 '   Hence we can produce A from B by the equation                       ';
 '                                                                       ';
 '                    A = inv(W)*B                                       ';
 '_______________________________________________________________________';
 '4. If we selected enough row operations to reduce A to its reduced row ';
 '   echelon form, then by the argument above there is an invertible     ';
 '   matrix W so that                                                    ';
 '                        W * A = rref(A)                                ';
 '                                                                       ';
 '   Thus we have a matrix equation for reduced row echelon form.        ';
 '_______________________________________________________________________';
 '5. From 4 we have that matrix A can be written in the form             ';
 '                                                                       ';
 '                         A = inv(W) * rref(A)                          ';
 '                                                                       ';
 '   which we can interpret as saying A can be "factored" into the       ';
 '   product of a nonsingular matrix and its reduced row echelon form.   '];
ob3=...
['6. The inverse of an elementary matrix is an elementary matrix of the    ';
 '   same kind.                                                            ';
 '_________________________________________________________________________';
 '7. Inverse of an elementary matrix E is easy to construct. We really do  ';
 '   not need to use a command like inverse or inv or even rref([E I]).    ';
 '                                                                         ';
 '   There is a pattern to the inverse for each type of elementary matrix. ';
 '   Patterns often imply that we can use them to get new results. In fact ';
 '   because of the patterns for the inverses for elementary matrices we   ';
 '   can get another way to solve a linear system by "factoring" the       ';
 '   coefficient matrix A. We discuss this elsewhere.                      ';
 '_________________________________________________________________________'];

%begin routine
clc
disp(title1),disp(s0),disp(title2),disp(s0),disp(intro),disp(s0),disp(s0)
disp(['     ******' s11]),pause

while 1
   clc
   disp(title1),disp(s0),disp(s0)
   disp(menu)
   disp(s0)
   chm=input(s10);

   if chm==0,clc,disp(s12),disp(s0),break
   end
   if chm==1,clc,disp(def),disp(s17),pause
   end
   if chm==2,clc,disp(con1),disp(s0),disp(con2),disp(mat1),disp(s18),pause
             disp(con3),disp(s0),disp(mat2),disp(s18),pause
             disp(con4),disp(s0),disp(mat3),disp(s11),pause
   end
   if chm==3
      uc1='n';
      while uc1=='n'
          clc,disp(use1),disp(s0),disp(use2),chuse=input(s10);
          if chuse==1
             tryuse='n';
             while tryuse=='n'
               disp('Enter 3 by 3 matrix A between square brackets')
               disp('with entries separated by a space and rows ending')
               disp('a semicolon.')
               matA=input('A = ');
               [m,n]=size(matA);
               if m==3 & n==3
                  A=matA;disp('Your matrix is;'),A
                  disp(s11),pause
                  tryuse='y';uc1='y';
               else
                  disp('Matrix size is incorrect. Try again.')
                  disp(s11),pause
                  tryuse='n';
               end
             end %while tryuse=='n'
          end
          if chuse==2 %MATLAB generates the matrix
             num=input('Enter your favorite number.  num = ');
             rand('seed',num);A=fix(10*rand(3));uc1='y';
             disp('The matrix generated is:'),A,disp(s11),pause
          end
          if chuse==0
             uc1='y';
          end
       end %while uc1=='n'
       modeok='n';
       while modeok=='n'
          clc,disp(usetitle),disp(s0),disp(use4),disp(s0)
          mode=input(s10);
          if mode==1,modeok='y';end
          if mode==2,modeok='y';end
       end %while modeok=='n'
       if mode==1,rsig='T';else,rsig='F';end
       chok='n';oldA=A;i=sqrt(-1);mess=usetitle;
       while chok=='n'
          clc,disp(mess),disp(s0)
          %*******put reduce stuff here
          disp(s9)
          a=A; %to prevent case mismatch in multiplier choice
          if rsig=='T',format rational,disp(A),format compact;else,A,end
          disp(use3)
          ch=input(s10);
          if ch==-1
             A=oldA;
             mess=s7;
          end
          if ch==0
             clc,chok='y';
             break
          end
          if ch==1
             sig='Y';
             j=input(s1);
             k=input(s2);
             aj=abs(fix(j));ak=abs(fix(k));
             if j~=aj | j>m | k~=ak | k>m | j==0 | k==0
                disp(s13)
                disp(s11)
                pause
                sig='N';
                mess=s0;
             end
             if sig=='Y'
                oldA=A;
                temp=A(j,:);
                A(j,:)=A(k,:);
                A(k,:)=temp;
                mess=s14;
             end
             %Do elem. matrix correspondence
             clc,st=['interchange row ' int2str(j) ' with row ' int2str(k)];
             disp(s23),disp(s0),disp([s20 st s21]),disp(s0)
             I=eye(3);temp=I(j,:);I(j,:)=I(k,:);I(k,:)=temp;E=I;
             if mode==1
                format rational,disp(E),format compact
             else
                disp(E)
             end
             disp(s0),disp(s22),disp(s0),disp(s24),disp(s0)
             if mode==1
                format rational,disp(oldA),format compact
             else
                disp(oldA)
             end
             disp(s0),disp(s25),disp(s0)
             if mode==1
                format rational,disp(A),format compact
             else
                disp(A)
             end
             disp(s0),disp(s11),pause
          end
          if ch==2
             sig='Y';
             k=input(s3);
             while (k==0)
                k=input(s4);
             end
             j=input(s5);
             aj=abs(fix(j));
             if j~=aj | j>m | j==0
                disp(s13)
                disp(s11)
                pause
                sig='N';
                mess=s0;
             end
             if sig=='Y'
                oldA=A;
                A(j,:)=k*A(j,:);
                mess=s15;
             end
             %Do elem. matrix correspondence
             clc,st=['multiply row ' int2str(j) ' by ' num2str(k)];
             disp(s23),disp(s0),disp([s20 st s21]),disp(s0)
             I=eye(3);I(j,:)=k*I(j,:);E=I;
             if mode==1
                format rational,disp(E),format compact
             else
                disp(E)
             end
             disp(s0),disp(s22),disp(s0),disp(s24),disp(s0)
             if mode==1
                format rational,disp(oldA),format compact
             else
                disp(oldA)
             end
             disp(s0),disp(s25),disp(s0)
             if mode==1
                format rational,disp(A),format compact
             else
                disp(A)
             end
             disp(s0),disp(s11),pause
          end
          if ch==3
             sig='Y';
             t=input(s3);
             k=input(s1);
             j=input(s6);
             aj=abs(fix(j));ak=abs(fix(k));
             if j~=aj | j>m | k~=ak | k>m | k==0 | j==0
                disp(s13)
                disp(s11)
                pause
                sig='N';
                mess=s0;
             end
             if sig=='Y'
                oldA=A;
                A(j,:)=t*A(k,:)+A(j,:);
                for ii=1:n,if abs(A(j,ii))<=myeps,A(j,ii)=0;end,end
                mess=s16;
             end
             %Do elem. matrix correspondence
             clc,st=['add ' num2str(t) ' times row ' int2str(k)];
                 st = [st  ' to row ' num2str(j)];
             disp(s23),disp(s0),disp([s20 st s21]),disp(s0)
             I=eye(3);I(j,:)=t*I(k,:)+I(j,:);E=I;
             if mode==1
                format rational,disp(E),format compact
             else
                disp(E)
             end
             disp(s0),disp(s22),disp(s0),disp(s24),disp(s0)
             if mode==1
                format rational,disp(oldA),format compact
             else
                disp(oldA)
             end
             disp(s0),disp(s25),disp(s0)
             if mode==1
                format rational,disp(A),format compact
             else
                disp(A)
             end
             disp(s0),disp(s11),pause
          end
       end %chok=='n'
   end %end of choice 3
   if chm==4
      uc1='n';
      while uc1=='n'
          clc,disp(inv1),disp(s0),disp(invmenu),chuse=input(s10);
          if chuse==1
             clc,disp(inv2),disp(s11),pause
          end
          if chuse==2 
             clc,disp(inv3a),disp(inv3b),disp(s11),pause
          end
          if chuse==3
             clc,disp(inv4a),disp(inv4b),disp(s11),pause
          end
          if chuse==0
             uc1='y';
          end
       end %while uc1=='n'
   end
   if chm==5
      clc,disp(obtitle),disp(ob1),disp(s11),pause
      clc,disp(ob2),disp(s11),pause
      clc,disp(ob3),disp(s11),pause
   end
end %while 1
