function fernifs(v,k) %previous update 9/16/98  last update 6/23/2015
%FERN IFS     Iterated Function System for a fern.
%             A picture is generated is called a Barnsley fern.
%             Use in the form  ==> fernifs(v,k)  <==
%             where
%                   v = [x y] is a point to start the iteration
%                   k = the number of composites to form
%                       (k should be large.)
%             If no value of k is specified k = 20000 is used.
%
%             This IFS has four transformations, but the probabilities
%             assigned are not equal.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%Data for the IFS taken from A Better Way to Compress Images, 
%                            by M. Barnsley and A. Sloan
%                            BYTE, Jan. 1988 PP215-223
%
%See also                    Iterated Function Systems 
%                            and Fractal Image Compression, 
%                            by Jeff Colvin, 1996
% See,  www.public.usit.net/kd4syw/fractal.html
%

%affine transformation data
A1=[0 0;0 .16];b1=[0 0]';           %probability p =0.01
A2=[.85 .04;-.04 .85];b2=[0 1.6]';  %probability p =0.85
A3=[.2 -.26; .23 .22];b3=[0 1.6]';  %probability p =0.07
A4=[-.15 .28; .26 .24];b4=[0 .44]'; %probability p =0.07

%the transformations
T1='A1*v+b1';
T2='A2*v+b2';
T3='A3*v+b3';
T4='A4*v+b4';

v=v(:);
if nargin==1,k=20000;,end

ax=[-4 4 0 11];
figure
axis(ax);axis(axis);axis('square');hold on
title('A Barnsley Fern.')
%plot(v(1),v(2),'ko')
%drawnow
for j = 1:k
    val=rand;
    if val<=.01
       v=eval(T1);
    end
    if val>.02 & val<=.86
       v=eval(T2);
    end
    if val>.87 & val<=.93
       v=eval(T3);
    end
    if val>.94 & val<=1
       v=eval(T4);
    end
    plot(v(1),v(2),'k.','markersize',6)
    drawnow
end
xlabel('Routine is over. Press ENTER twice.')
pause