%          <<updated 12/5/00;  6/26/2015
%GSPRAC2  Practice for the Gram-Schmidt process with 2-vectors.
%         A pair of linearly independent 2-vectors are transformed
%         into an orthogonal set and then normalized to form an
%         orthonormal set. The process is shown step-by-step graphically
%         and algebraically. The user must enter an appropriate coefficient
%         for the linear combination involved. You may enter a fraction or
%         a decimal accurate to four or more places.
%
%         Follow the directions that appear in the MESSAGE WINDOW.
%
%         A set of built-in vector pairs can be chosen or you can enter
%         your own pair of 2-vectors.
%
%  Use in the form  ===>  gsprac2  <===
%                 
%  Uses utility mat2strh and gschmidt.
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%strings
s0=' ';
s1='Your choice --> ';
s2='Displaying and graphing the vectors.';
s3='Starting the GRAM-Schmidt process.';
s4='Set new vector v1 = q1.';
s5='Construct v2 as a linear combination';
s6='of v1 and q2 so that it is orthogonal';
s7='to v1.';
s8='The number we seek here is';
s9=' v1''q2    Compute it. Click in the';
s10='-------     yellow box and type it.';
s11=' v1''v1   Then press ENTER. ';
s12='         (Use 4 or more dec. places.)';
s13='Number entered is valid.';
s14='Number entered is INCORRECT.';
s15='Press ENTER to try again.';
s16='The orthogonal pair v1 and v2';
s17='are shown graphically.';
s18='Next we make v1 and v2 unit vectors.';
s19='See the display and the graph.';
s20='Click on QUIT or RESTART.';
s21='The ORTHONORMAL pair, u1 and u2.';

cont1='Click in the Message Window then Press ENTER.';
cont='Press Enter to continue.';
head=[blanks(30) 'GSPRAC2'];
head1=['BRIEF description/directions.'];
menu=['<1> Continue with Gram-Schmidt process.';
      '                                       ';
      '<0> Quit.                              '];

menu1=['<1> Enter a pair of 2-vectors.                            ';
       '                                                          ';
       '<2> Choose a built-in demo of a pair of 2-vectors.        ';
       '                                                          ';
       '<0> Quit.                                                 '];

demodata=['Choice #1       Choice #2     Choice #3      Choice #4 ';
          '                                                       ';
          '     1                5             1             -2   ';
          'q1 =             q1 =          q1 =           q1 =     ';
          '     1                3            -4              1   ';
          '                                                       ';
          '     1               -2             1              1   ';
          'q2 =             q2 =          q2 =           q2 =     ';
          '     2                1             1             -1   '];

clrs=['brm']; %colors  blue red magenta 

n=2; %size of the n-vectors

%things that are evaled
%
%plotting the original vectors
pltorig='subplot(gr1sub),axis(ax),axis(axis),axis(''square''),hold on,';
pltorig=[pltorig 'plot([0 q1(1)],[0 q1(2)],[clrs(1) ''-''],'];
pltorig=[pltorig '[0 q2(1)],[0 q2(2)],[clrs(2) ''-''],'];
pltorig=[pltorig '''linewidth'',2);'];
pltorig=[pltorig 'grid on;'];
pltorig=[pltorig 'title(''The VECTORS'',''fontweight'',''bold'',''fontsize'',14);'];
pltorig=[pltorig 'xlabel(''Original vectors: q1 and q2 .'','];
pltorig=[pltorig '''fontweight'',''bold'',''fontsize'',14);'];
pltorig=[pltorig 'subplot(messsub),ml1=text(.05,.9,s2,''color'',''k'','];
pltorig=[pltorig '''fontweight'',''bold'',''fontsize'',14);'];
pltorig=[pltorig 'ml2=text(.05,.1,cont1,''color'',''k'','];
pltorig=[pltorig '''fontweight'',''bold'',''fontsize'',14);'];
pltorig=[pltorig 'pause,delete(ml1),delete(ml2),'];

%showing the original vectors as a display
showvecs='subplot(vecsub),q1m=text(0,.5,''q1 = '',''fontweight'',''bold'',';
showvecs=[showvecs '''color'',clrs(1),''fontsize'',14);'];
showvecs=[showvecs 'text(.1,.7,mat2strh(q1(1),2),''fontweight'',''bold'','];
showvecs=[showvecs '''color'',clrs(1),''fontsize'',14);'];
showvecs=[showvecs 'text(.1,.3,mat2strh(q1(2),2),''fontweight'',''bold'','];
showvecs=[showvecs '''color'',clrs(1),''fontsize'',14);'];
showvecs=[showvecs 'q2m=text(.4,.5,''q2 = '',''fontweight'',''bold'','];
showvecs=[showvecs '''color'',clrs(2),''fontsize'',14);'];
showvecs=[showvecs 'text(.5,.7,mat2strh(q2(1),2),''fontweight'',''bold'','];
showvecs=[showvecs '''color'',clrs(2),''fontsize'',14);'];
showvecs=[showvecs 'text(.5,.3,mat2strh(q2(2),2),''fontweight'',''bold'','];
showvecs=[showvecs '''color'',clrs(2),''fontsize'',14);'];

%setting up box to enter coefficient
entrybox=[ 'subplot(infosub);c1box=uicontrol(''Style'',''edit'',''units'',''normal'','];
entrybox=[entrybox '''position'',[.13 .55 .15 .05],''back'',''y'',''fontsize'',14,'];
entrybox=[entrybox '''fontweight'',''bold'',''HorizontalAlignment'',''left'','];
entrybox=[entrybox '''call'', ''eval(havc1)'');'];

%getting entered value from entrybox & initiating check
havc1='c1val=str2num(get(c1box,''string''));eval(c1check)';

%checking if value entered in entrybox is valid
c1check='delete(ml1),delete(ml2),delete(ml3),delete(ml4),delete(ml5),';
c1check=[c1check 'if abs(c1val-c1true)<1.e-3,subplot(messsub),'];
c1check=[c1check 'ml1=text(.05,.9,s13,''color'',''k'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);delete(c1box);subplot(infosub);'];
c1check=[c1check 'delete(v2disp),'];
c1check=[c1check 'c1coeff=text(0,.55,[''v2 = q2 - ('' num2str(c1val) '')*v1''],'];
c1check=[c1check '''color'',''m'',''fontweight'',''bold'',''fontsize'',14);'];
c1check=[c1check 'text(0,.4,''v2 = '',''color'',''m'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);'];
c1check=[c1check 'text(.18,.45,num2str(v2(1)),''color'',''m'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);'];
c1check=[c1check 'text(.18,.35,num2str(v2(2)),''color'',''m'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);subplot(messsub),'];
c1check=[c1check 'ml2=text(.05,.5,cont1,''color'',''k'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);'];
c1check=[c1check 'pause,delete(ml1),delete(ml2),eval(havorth2),'];
c1check=[c1check 'else,subplot(messsub),'];
c1check=[c1check 'ml1=text(.05,.9,s14,''color'',''k'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);'];
c1check=[c1check 'ml2=text(.05,.5,s15,''color'',''k'',''fontweight'','];
c1check=[c1check '''bold'',''fontsize'',14);'];
c1check=[c1check 'pause,delete(c1box),delete(ml1),delete(ml2),'];
c1check=[c1check 'eval(showc1mess),eval(entrybox),end'];

%showing the message on how to compute the coefficient
showc1mess='subplot(messsub),ml1=text(.05,.9,s8,''color'',''k'',';
showc1mess=[showc1mess '''fontweight'',''bold'',''fontsize'',14);'];
showc1mess=[showc1mess 'ml2=text(.05,.7,s9,''color'',''k'','];
showc1mess=[showc1mess '''fontweight'',''bold'',''fontsize'',14);'];
showc1mess=[showc1mess 'ml3=text(.05,.5,s10,''color'',''k'','];
showc1mess=[showc1mess '''fontweight'',''bold'',''fontsize'',14);'];
showc1mess=[showc1mess 'ml4=text(.05,.3,s11,''color'',''k'','];
showc1mess=[showc1mess '''fontweight'',''bold'',''fontsize'',14);'];
showc1mess=[showc1mess 'ml5=text(.05,.1,s12,''color'',''k'','];
showc1mess=[showc1mess '''fontweight'',''bold'',''fontsize'',14);'];

%things after we have the orthogonal pair
havorth2='subplot(gr1sub),plot([0 v2(1)],[0 v2(2)],''m-'',';
havorth2=[havorth2 '''linewidth'',2);'];
havorth2=[havorth2 'v1n=text(v1(1),v1(2),''v1'',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'v2n=text(v2(1),v2(2),''v2'',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'subplot(messsub),'];
havorth2=[havorth2 'ml1=text(.05,.9,s16,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'ml2=text(.05,.7,s17,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'ml3=text(.05,.1,cont1,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'pause,delete(ml1),delete(ml2),delete(ml3),'];
havorth2=[havorth2 'ml1=text(.05,.9,s18,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'ml2=text(.05,.7,s19,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);pause(2),subplot(infosub);'];
havorth2=[havorth2 'text(0,.25,s21,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(0,.1,''u1 = '',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(.18,.15,num2str(u1(1)),''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(.18,.05,num2str(u1(2)),''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(.5,.1,''u2 = '',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(.68,.15,num2str(u2(1)),''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'text(.68,.05,num2str(u2(2)),''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'subplot(gr1sub),delete(v1n),delete(v2n),pause(2),'];
havorth2=[havorth2 'plot([0 u1(1)],[0 u1(2)],''k-'','];
havorth2=[havorth2 '''linewidth'',2);'];
havorth2=[havorth2 'plot([0 u2(1)],[0 u2(2)],''k-'','];
havorth2=[havorth2 '''linewidth'',2);'];
havorth2=[havorth2 'u1n=text(u1(1),u1(2),''u1'',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'u2n=text(u2(1),u2(2),''u2'',''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];
havorth2=[havorth2 'pause(1),subplot(messsub),'];
havorth2=[havorth2 'ml3=text(.05,.1,s20,''color'',''k'',''fontweight'','];
havorth2=[havorth2 '''bold'',''fontsize'',14);'];


%callbacks  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%for quit button
done='close(gcf),clc,disp(''GSPRAC2 is over!''),return';

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

%data input
typeok='N';
while typeok=='N';
   clc,disp(head),disp(s0),disp(head1),disp(s0)
   disp(menu1)
   disp(s0)
   ch=input(s1);if isempty(ch),ch=99;,end
   if ch==2
      clc,disp(head),disp(s0)
      disp('Demo choices are:'),disp(demodata),disp(s0)
      democh=input(s1);if isempty(democh),democh=99;,end
      if democh~=1 & democh~=2 & democh~=3 & democh~=4
         disp(s0)
         disp('Improper choice. Press ENTER to begin again.')
         pause
      else
         typeok='Y';
      end
      if democh==1,q1=[1 1]';q2=[1 2]';A=[q1 q2];end
      if democh==2,q1=[5 3]';q2=[-2 1]';A=[q1 q2];end
      if democh==3,q1=[1 -4]';q2=[1 1]';A=[q1 q2];end
      if democh==4,q1=[-2 1]';q2=[1 -1]';A=[q1 q2];end    
   end
   if ch==0,clc,disp('GSPRAC2 is over!'),return,end
   if ch==1
      dataok='N';
      while dataok=='N'
         clc,disp(head),disp(s0)
         disp('Enter a 2-vector in the form [1 2]')
         disp(s0)
         q1=input('vector q1 = ');q1=q1(:);  %making vector a column
         disp(s0)
         disp('Enter another 2-vector in the form [3 4]')
         disp(s0)
         q2=input('vector q2 = ');q2=q2(:);  %making vector a column
         disp(s0)
         A=[q1(:) q2(:)];
         [nA mA]=size(A);
         matsum=sum(sum(A));
         imck=sum(sum(imag(A)));
         if nA~=2 | mA~=2 | imck~=0 | matsum==0 | abs(det(A))<100*eps
            disp('Vectors q1 and q2 must be 2-vectors with real entries.')
            if matsum==0
               disp('Some entries must be nonzero.')
            end           
            if abs(det(A))<100*eps
               disp('Your vectors are not linearly independent.')
            end
            disp(s0),disp(cont),pause
         else      
            dataok='Y';typeok='Y';
         end
       end
   end
end


choiceok='N';
while choiceok=='N'
   format compact
   clc,disp(head)
   disp('Your vectors are displayed as the following columns.')
   disp(s0),disp(A)
   disp(s0)
   disp(menu),disp(s0)
   choice=input(s1);if isempty(choice),choice=99;,end
   if choice==0,clc,disp('GSPRAC2 is over!'),return,end
   if choice~=1
      disp(s0),disp('<><><>Improper choice; try again.')
      disp(cont)
      pause
   else
      choiceok='Y';format
   end
end

%setting numeric quantities
v1 = q1;
c1true=(v1'*q2)/(v1'*v1);
v2=q2-c1true*v1;
u1=v1/norm(v1);
u2=v2/norm(v2);

xl=min([q1(1) q2(1) v2(1)]);xr=max([q1(1) q2(1) v2(1)]);
yb=min([q1(2) q2(2) v2(2)]);yt=max([q1(2) q2(2) v2(2)]);
xsp=max([abs(xl) abs(xr)]);
ysp=max([abs(yb) abs(yt)]);
axval=max([xsp ysp]);
ax=axval*[-1 1 -1 1];      %axis setup

%DOING THE GRAPHICS 
%setting graphics window to full size
hfig=figure('units','normal','position',[0 0 1 1]);
axis('off')

%the subplots
titlesub=subplot('position',[.01 .95 .4 .08]);axis('off');
gr1sub=subplot('position',[.5 .45 .45 .45]);%axis('off');
vanitysub=subplot('position',[.6 .1 .15 .05]);axis('off');
messsub=subplot('position',[.05 .1 .4 .19]);axis('off');
infosub=subplot('position',[.01 .3 .38 .6]);axis('off');
vecsub=subplot('position',[.5 .2 .45 .2]);axis('off');


%doing title
subplot(titlesub)
text(0,0,'GRAM-SCHMIDT Demo','color','r','fontweight','bold',...
         'fontsize',20);


%doing vanity
subplot(vanitysub);
text(0,0,'by D.R.Hill','color','black','fontsize',14,'fontweight','bold',...
     'fontangle','oblique')  

%doing message window
subplot(messsub);
plot([0 0 1 1 0],[0 1 1 0 0],'-k','linewidth',2);
axis('off')
title('MESSAGE WINDOW','color','blue','fontsize',14);


%buttons for help/quit/etc
hbutfrm=uicontrol('style','frame','units','normal',...
                 'position',[.84 .07 .14 .16],'backgroundcolor','y');

helpbut = uicontrol('style','push','units','normal','pos',[.85 .18 .12 .04], ...
        'string','HELP','fontweight','bold','fontsize',14,...
        'call','set(gcf,''visible'',''off'');clc,help gsprac2,disp(cont),pause,set(gcf,''visible'',''on'');');

restbut = uicontrol('style','push','units','normal','pos',[.85 .13 .12 .04], ...
        'string','RESTART','fontweight','bold','fontsize',14,...
        'call','close(gcf),gsprac2');

quitbut = uicontrol('style','push','units','normal',...
          'pos',[.85 .08 .12 .04],'string','QUIT',...
          'fontweight','bold','fontsize',14,'call',done);


%INTRO
eval(showvecs)
eval(pltorig)

%solving so we have the answers
Aorth=gschmidt(A,1);
Aornorm=gschmidt(A);

%Step #1 of GS
subplot(messsub)
ml1=text(.05,.9,s3,'color','k','fontweight','bold','fontsize',14);
pause(1)
ml2=text(.05,.5,s4,'color','k','fontweight','bold','fontsize',14);
subplot(infosub)
text(0,.95,'Step #1','color','k','fontweight','bold','fontsize',14);
text(0,.8,'v1 = q1 = ','color','b','fontweight','bold','fontsize',14);
text(.33,.85,mat2strh(q1(1)),'color','b','fontweight','bold','fontsize',14);
text(.33,.75,mat2strh(q1(2)),'color','b','fontweight','bold','fontsize',14);
pause(1)

subplot(messsub)
ml3=text(.05,.1,cont1,'color','k','fontweight','bold','fontsize',14);
pause,delete(ml1),delete(ml2),delete(ml3)

%step #2 of GS
subplot(messsub)
ml1=text(.05,.9,s5,'color','k','fontweight','bold','fontsize',14);
ml2=text(.05,.7,s6,'color','k','fontweight','bold','fontsize',14);
ml3=text(.05,.5,s7,'color','k','fontweight','bold','fontsize',14);


subplot(infosub)
text(0,.65,'Step #2','color','k','fontweight','bold','fontsize',14);
v2disp=text(0,.55,'v2 = q2 - (a number)*v1','color','m',...
                  'fontweight','bold','fontsize',14);

subplot(messsub)
ml4=text(.05,.1,cont1,'color','k','fontweight','bold','fontsize',14);
pause,delete(ml1),delete(ml2),delete(ml3),delete(ml4)



eval(showc1mess)

%insert editable text for coeff.

eval(entrybox)
