function hfractal(p,rfactor) %Prev. update 7/28/98  last update 6/23/2015
%Hfractal    Draws the H fractal for p steps using a reduction factor.
%
%        Use in the form  ==>  hfractal(p,rfactor)  <==
%        p an integer > 1
%        rfactor in (0,.7)
%        
%        Adapted from Fractals, Endlessly Repeated Geometric Figures
%                by   Hans Lauwerier
%                     Princeton University Press, 1991
%                     ISBN 0-691-02445-6
%
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu


if p<=0 | fix(p)~=p
   disp('Error: Input value of p must be a positive integer.')
   return
end
if rfactor<=0 | rfactor>=.71 
   disp('Error: Input value of rfactor must be between 0 and 0.7 .')
   return
end

gcode='N';
while gcode=='N'
   clc
   if p >= 10
      disp(['Warning: Lots of line segments will be drawn.'])
      disp('This may require a lot of time.')
      disp(' ')
      val=input('Press 0 to quit; press 1 to continue.');
      if val==0,return,end
      if val==1,gcode='Y';end
   else
      gcode='Y';
   end
end %while

%note: p is the order
%      rfactor is the reducton factor

a = rfactor;

%Setting up the axes
figure
ax=[-2.5,2,-2.5,2];  %this can be adjusted in needed.
axis(ax);axis(axis);axis('square');hold on
title(['H-FRACTAL using ' num2str(p) ' steps with reduction factor ' num2str(rfactor)])

%doing the H's
%
x(1)=0;y(1)=0;
for m=0:p
   s=mod(m,2);
   for n=2^m:2^(m+1)-1
       if s==1
          x(2*n)=x(n);y(2*n)=y(n)+a^m;
          x(2*n+1)=x(n);y(2*n+1)=y(n)-a^m;
       else
          x(2*n)=x(n)+a^m;y(2*n)=y(n);
          x(2*n+1)=x(n)-a^m;y(2*n+1)=y(n);
       end
    end
end

for n=1:2^(p+1)-1
    if n>=1 | n>=2^5, clr='-k';end
    if n>=2 & n<2^2, clr='-r';end
    if n>=2^2 & n<2^3,clr='-b';end
    if n>=2^3 & n<2^4,clr='-m';end
    if n>=2^4 & n<2^5,clr='-g';end
    plot([x(2*n) x(2*n+1)],[y(2*n) y(2*n+1)],clr)
    drawnow
    if p<=4,pause(1),end
end
xlabel('Routine is over. Press ENTER.')