%INTERPIT   Interactive polynomial interpolation    
%           updated 9/13/98; 6/25/2015
%
%        An interactive routine that lets you choose data points
%        using the mouse through which an interpolation polynomial
%        will be constructed. Selection of integer
%        point values or decimal point values can be made.
%       
%        Uses routine myginput.
%  
%        Use in the form   ===>  interpit   <===
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

%NOTES: On 11/18/97 Tech Supp Ref Number 153643 indicated a change from 'fullcrosshair'
%to 'crosshair' would fix the vanishing cursor problem I was having. I made this change in
%ginput and called the routine myginput.

%locations info about the lines messages
%
locsum1=[-.15 .85;-.15 .8;-.15 .55;-.15 .50;-.15 .35;-.15 .30];

%STRINGS
%

mess1='Selection out of range.';
mess2='Select point again in the box.';

header='INTERPIT';
seehead=['                     ';
         '                     ';
         'The selected data is:';
         '                     '];

polyhead=['                                ';
          '                                ';                
          'The interpolating polynomial is:';
          '                                '];

bp=setstr(7);
beep=[ bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp...
            bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp...
            bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp bp];

s0=' ';
s1='                     Interpolation with polynomials';
s2='DATA ENTRY';
s3='INTERPIT is over!';
cont='Press ENTER to continue.';

mousedat=['      Directions for Selecting Data Using the Mouse       ';
          '                                                          ';
          'In the graph box, position the mouse at a point and click ';
          'to record the coordinates of the point. Choose at least   ';
          'two points. Type q to quit selecting points.              ';
          'The data points will be plotted.                          ';
          '                                                          ';
          'If integer selection is chosen the value selected will be ';
          'the nearest integer pair to the mouse position.           ';
          '                                                          ';
          'Stay within the graphics box for data selection otherwise ';
          'the results may be erratic.                               ';
          '                                                          ';
          'Warning: Select integer or decimal mode before clicking on';
          'the data selection button.                                ';
          '                                                          '];
%=======================================================================
%Code for setting color definition to emulate MATLAB version 4
%within version 5.
%The idea is to try to use the same code for version 4 as 5 with the 
%
vers=version;vers=vers(1);
if vers=='S' | vers=='s',vers='4';end
%specstr='colordef none';
%specstr1='colordef white';    %upon exiting we execute colordef white
versnum=str2num(vers);
%if vers>='5',eval(specstr),end
%=======================================================================

%integer grid values; used in 'integer' selection mode
%
rval=[-10 10 -10 10];
vals=rval(1):rval(2)/10:rval(2);

%initializing switch for data selection
%
dsw='N'; %meaning no data selected

%routine for displaying the polynomial; coefficients assumed to be in c
%
showpoly='nc=length(c);for ii=1:nc,';
showpoly=[showpoly 'if c(ii)<0,st=''-'';else,'];
showpoly=[showpoly 'st=''+'';end,'];
showpoly=[showpoly 'if ii==1 & c(1)>0,st='' '';end,'];
showpoly=[showpoly 'st=[st num2str(abs(c(ii))) '' * x ^'' int2str(nc-ii)];'];
showpoly=[showpoly 'disp(st),end'];

%callback for the help button
helps='set(gcf,''visible'',''off'');clc,help interpit,';
helps=[helps 'disp(mousedat),disp(cont),pause,set(gcf,''visible'',''on'');'];
%

%CALL back for done button
done = 'close(gcf),clc,disp(s3)';%callback for quit button
%

%callback for Select Data
%
datapts='if dsw==''Y'',';
datapts=[datapts 'set(txtHndl,''string'','];
datapts=[datapts '''Data has been selected.'',''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'set(txtHndl1,''string'',''Press RESTART to select new data.'',''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'disp(beep),pause(4),'];
datapts=[datapts 'set(txtHndl,''string'',s0);'];
datapts=[datapts 'set(txtHndl1,''string'',s0);'];

%checking if data already selected

datapts=[datapts 'else,'];
datapts=[datapts 'set(txtHndl,''string'','];
datapts=[datapts '''Use mouse to select data points.'',''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'set(txtHndl1,''string'','];
datapts=[datapts '''Type q to quit selecting points.'',''fontsize'',14,''fontweight'',''bold'' );'];
datapts=[datapts 'dsw=''Y'';'];
datapts=[datapts 'axes(grbox);'];%selecting data
datapts=[datapts 'dmat=[];'];
%code for showing point coord as selected
%datapts=[datapts 'datpr=text(locsum1(1,1),locsum1(1,2),'];
%datapts=[datapts '''POINTS '',''color'',''blue'');'];
%datapts=[datapts 'drawnow;'];
datapts=[datapts 'over=''N'';while over==''N'''];
datapts=[datapts 'axes(grbox);'];
datapts=[datapts 'validpt=''N'';while validpt==''N'',[x1,y1,z]=myginput(1);'];
datapts=[datapts 'if abs(z)==''q'' | abs(z)==''Q'';over=''Y'';'];
datapts=[datapts 'set(txtHndl,''string'',s0);'];
datapts=[datapts 'set(txtHndl1,''string'',s0);break,else,'];
%clearing message
datapts=[datapts 'if abs(x1)<rval(2) & abs(y1)<rval(2),validpt=''Y'';'];
datapts=[datapts 'else,disp(beep),set(txtHndl,''string'',mess1,''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'pause(3),set(txtHndl,''string'',mess2,''fontsize'',14,''fontweight'',''bold'');pause(4),'];
datapts=[datapts 'set(txtHndl,''string'',s0);end;end;end;'];   

datapts=[datapts 'if intsw==''Y'',[mv mi]=min(abs(vals-x1));x1=vals(mi);'];
datapts=[datapts '[mv mi]=min(abs(vals-y1));y1=vals(mi);end,'];
datapts=[datapts 'if over==''N'','];
datapts=[datapts 'pt1l1=[''Point: ('' num2str(x1) '','' num2str(y1) '')''];'];
datapts=[datapts 'axes(grbox);'];
datapts=[datapts 'plot(x1,y1,''ob'',''linewidth'',2);drawnow;'];
datapts=[datapts 'dmat=[dmat;[x1 y1]];end;'];
datapts=[datapts 'end,']; %of select data 
datapts=[datapts 'pause(2);'];
datapts=[datapts 'dupsig=''N'';xs=sort(dmat(:,1));v=xs(1);'];
datapts=[datapts 'for ii=2:length(xs),if v==xs(ii),dupsig=''Y'';'];
datapts=[datapts 'else,v=xs(ii);end,end,if dupsig==''Y'','];
datapts=[datapts 'set(txtHndl,''string'','];
datapts=[datapts '''Data NOT distinct.'',''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'set(txtHndl1,''string'',''Results maybe erratic.'',''fontsize'',14,''fontweight'',''bold'');'];
datapts=[datapts 'disp(beep),pause(4),end,'];
%checking for nondistinct data
datapts=[datapts 'eval(doint);'];
datapts=[datapts 'end'];

%Setting up
%do interpolation button
%
doint='dointbut=uicontrol(''style'',''push'',''units'',''normal'',';
doint=[doint '''backgroundcolor'',''y'',''pos'',[.05 .75 .25 .05],'];
doint=[doint '''string'',''Construct interpolant.'',''fontsize'',14,''fontweight'',''bold'','];
doint=[doint '''foregroundcolor'',''b'',''call'',bdint);'];
doint=[doint 'seebut=uicontrol(''style'',''push'',''units'',''normal'','];
doint=[doint '''backgroundcolor'',''y'',''pos'',[.05 .65 .25 .05],'];
doint=[doint '''string'',''See the data set.'',''fontsize'',14,''fontweight'',''bold'','];
doint=[doint '''foregroundcolor'',''b'',''call'',seedat);'];
doint=[doint 'refresh(gcf);'];

%callback for interp button
%
bdint=...
'set(txtHndl,''string'',''Computing interpolant.'',''fontsize'',14,''fontweight'',''bold'');pause(3);';
bdint=[bdint 'set(txtHndl1,''string'',s0);'];
bdint=[bdint 'c=polyfit(dmat(:,1),dmat(:,2),length(dmat(:,1))-1);'];
bdint=[bdint 'coeff=c;'];
%coefficient of polynomial are in c
bdint=[bdint 'x=-10:.1:10;y=polyval(c,x);'];
bdint=[bdint 'axes(grbox);plot(x,y,''-r'',''linewidth'',2);'];
bdint=[bdint 'plot(dmat(:,1),dmat(:,2),''*b'',''linewidth'',2 );pause(3);'];
bdint=[bdint 'dointbut=uicontrol(''style'',''push'',''units'',''normal'','];
bdint=[bdint '''backgroundcolor'',''y'',''pos'',[.05 .55 .30 .05],'];
bdint=[bdint '''string'',''See interpolating polynomial.'',''fontsize'',14,''fontweight'',''bold'','];
bdint=[bdint '''foregroundcolor'',''b'',''call'',seepoly);'];
%inserting see poly button
bdint=[bdint 'set(txtHndl,''string'',s0);'];
%clearing message


%callback for see data button
%
seedat=...
'set(txtHndl,''string'',''Showing the data set.'',''fontsize'',14,''fontweight'',''bold'');';
seedat=[seedat 'set(txtHndl1,''string'',s0);pause(1);'];
seedat=[seedat 'set(gcf,''visible'',''off'');clc,'];
seedat=[seedat 'disp(seehead),disp(dmat),'];
seedat=[seedat 'disp(cont),pause,set(gcf,''visible'',''on'');'];
seedat=[seedat 'set(txtHndl,''string'',s0);'];
%clearing message

%callback for see poly button
%
seepoly=...
'set(txtHndl,''string'',''Showing the interpolating polynomial .'',''fontsize'',14,''fontweight'',''bold'');';
seepoly=[seepoly 'set(txtHndl1,''string'',s0);pause(1);'];
seepoly=[seepoly 'set(gcf,''visible'',''off'');clc,'];
seepoly=[seepoly 'disp(polyhead),eval(showpoly),'];
seepoly=[seepoly 'disp(cont),pause,set(gcf,''visible'',''on'');'];
seepoly=[seepoly 'set(txtHndl,''string'',s0);'];
%clearing message

%COLOR settings
bkgr='white'; %background color
%

%Default selection is INTEGER
intsw='Y'; %setting integer selection switch to YES (ie on) as default


%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

%THE GUI STARTS HERE
hfig=figure('units','normal','position',[0 0 1 1],'color',bkgr);
axis('off')

%vanity
vanbox=subplot('position',[.85 .1 .1 .06]);axis('off');
text(0,0,'by D.R.Hill','color','black','fontsize',14,...
     'fontweight','bold','fontangle','oblique')

%TITLE
%
titlebox=subplot('position',[.05 .95 .5 .08]);axis('off');
titext=text(0,0,header,'color','m',...
            'fontsize',28,'fontweight','bold');
            

%START PUSH BUTTONS for Utility Functions + frame
%
utfrm=uicontrol('style','frame','units','normal',...
                 'position',[.04 .29 .34 .08],'backgroundcolor','y');
helph = uicontrol('style','push','units','normal','pos',[.05 .3 .1 .06], ...
        'string','Help','fontsize',14,'fontweight','bold','call',helps);
rstarth = uicontrol('style','push','units','normal','pos',[.16 .3 .1 .06], ...
        'string','Restart','fontsize',14,'fontweight','bold','call','close(gcf),interpit');
endh = uicontrol('style','push','units','normal','pos',[.27 .3 .1 .06], ...
        'string','QUIT','fontsize',14,'fontweight','bold','call','eval(done)');

%
%Button to refresh screen if graph gets screwed up.
%
if versnum<5
rfbut=uicontrol('style','push','units','normal','pos',[.80 .1 .15 .06], ...
        'string','Redraw Graph','fontsize',14,'fontweight','bold','call','refresh(gcf)');
end
%
%Button for select data
%

line1but=uicontrol('style','push','units','normal',...
                   'backgroundcolor','y',...
                   'pos',[.05 .85 .25 .05],...
                   'string','Select DATA Points',...
                   'fontsize',14,'fontweight','bold',...
                   'foregroundcolor','b',...
                   'call',datapts);
%
%Starting RADIO Buttons for display Mode + FRAME
%

butfrm=uicontrol('style','frame','units','normal',...
                 'position',[.55 .08 .2 .15],'backgroundcolor','y');
rbutint=uicontrol('style','radio','string','Select Integers',...
                  'fontsize',14,'fontweight','bold',...
                  'backgroundcolor','w',...
                  'units','normal','position',[.56 .17 .18 .05],... 
                  'value',1,...
                  'callback',['set(rbutint,''value'',1),'...
                              'set(rbutdec,''value'',0),'...
                              'intsw=''Y'';']);
rbutdec=uicontrol('style','radio','string','Select Decimals',...
                  'fontsize',14,'fontweight','bold',...
                  'backgroundcolor','w',...
                  'units','normal','position',[.56 .09 .18 .05],... 
                  'callback',['set(rbutdec,''value'',1),'...
                              'set(rbutint,''value'',0),'...
                              'intsw=''N'';']);
%
%MESSAGE area    Borrowed from a MathWorks Routine
    %===================================
    % Set up the Comment Window
    top=0.23;
    %top=0.18;
    left=0.05;
    right=0.5;
    bottom=.05;
    %bottom=0.05;
    labelHt=0.05;
    spacing=0.005;
    promptStr= ' ';

    % First, the Comment Window frame
    frmBorder=0.02;
    frmPos=[left-frmBorder bottom-frmBorder ...
	(right-left)+2*frmBorder (top-bottom)+2*frmBorder];
    uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',frmPos, ...
	'BackgroundColor',[0.50 0.50 0.50]);
    % Then the text label
    labelPos=[left top-labelHt (right-left) labelHt];
    uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'Position',labelPos, ...
        'BackgroundColor',[0.50 0.50 0.50], ...
	'ForegroundColor','white', ...
        'String','Comment Window','fontsize',14,'fontweight','bold');
    % Then the text field(s)
    
    txtPos=[left top-labelHt-2*frmBorder (right-left) labelHt];
    txtPos1=[left top-2*labelHt-2*frmBorder (right-left) labelHt];
    txtHndl=uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',txtPos, ...
        'String',promptStr,'fontweight','bold','foregroundcolor','red');
    txtHndl1=uicontrol( ...
	'Style','text', ...
        'Units','normalized', ...
        'BackgroundColor',[1 1 1], ...
        'Position',txtPos1, ...
        'String',promptStr,'fontweight','bold','foregroundcolor','red');
%first message
%
set(txtHndl,'string','Click on Button to select data points.','fontsize',14,'fontweight','bold');

%establish graphics box
%

grbox=axes('position',[.3 .3 .75 .65]);
plot([rval(1) rval(2)],[0 0],'-k',[0 0],[rval(1),rval(2)],'-k')
axis(rval);axis('square');axis(axis);
set(grbox,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(grbox,'xtick',[rval(1):rval(2)],'ytick',[rval(1):rval(2)],...
    'xgrid','on','ygrid','on');
hold on;




