function koch(p)  %previous update 9/16/98   last update 6/23/2015
%Koch    Draws the Koch curve at the pth step; 4^p line segments used.
%
%        Use in the form  ==>  koch(p)  <==
%        p an integer > 1
%        
%        Adapted from Fractals, Endlessly Repeated Geometric Figures
%                by   Hans Lauwerier
%                     Princeton University Press, 1991
%                     ISBN 0-691-02445-6
%
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu


if p<=0 | fix(p)~=p
   disp('Error: Input value of p must be a positive integer.')
end
number=4^p;
if p >= 5
   disp(['Warning: ' num2str(number) ' line segments will be drawn.'])
   disp('This may require a lot of time.')
   disp(' ')
   val=input('Press 0 to quit; any other key to go on.');
   if isempty(val)==1
      val=999;
   end   
   if val==0,return,end
end
    
%Setting up the axes
figure
ax=[-.1,1.1,-.4,.5];
axis(ax);axis(axis);hold on
h=3^(-p);
oldx=0;oldy=0;

for n = 1:4^p
    m=n-1;
    for l=1:p          %Getting quaternary number of the line segment.
        t(l)=mod(m,4);
        m=fix(m/4);
    end
    s=0;
    for k=1:p          %determining the slope of the line segment
        s=s+mod(t(k)+1,3)-1;
    end
    x=oldx+cos(pi*s/3)*h;
    y=oldy+sin(pi*s/3)*h;
    plot([oldx x],[oldy y],'-k')
    if n==1
       title(['Koch Curve with ' num2str(number) ' line segments.']) 
    end
    drawnow
    oldx=x;oldy=y;
end
xlabel('Routine is over. Press Enter.')