function kochifs(v,k)  %previous update 4/10/00  last update 6/23/2015
%KOCHIFS      Iterated Function System for the KOCH Curve
%             A picture is generated.
%             Use in the form  ==> kochifs(v,k)  <==
%             where
%                   v = [x y] is a point to start the iteration
%                       denoted by o in the picture provided it 
%                       is close enough to the figure. 
%
%                   k = the number of composites to form
%                       (2000 a pleasing picture)
%             If no value of k is specified k = 1000 is used.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%affine transformation data
A1=(1/3)*eye(2);
A2=[1/6 -sqrt(3)/6;sqrt(3)/6 1/6];
b2=[1/3 0]';
A3=[1/6 sqrt(3)/6;-sqrt(3)/6 1/6];
b3=[0.5 sqrt(3)/6]';
A4=[1/3 0;0 1/3];
b4=[2/3 0]';

%the transformations
T1='A1*v';
T2='A2*v+b2';
T3='A3*v+b3';
T4='A4*v+b4';

v=v(:);
if nargin==1,k=1000;,end

hfig=figure('units','normal','position',[0 0 1 1],'color','white');
axis('off')

tag=subplot('position',[.4 .08 .2 .05]);
axis('off')
mess=text(.3,.1,'Routine is over. Press ENTER.','fontsize',14,'fontweight','bold');
set(mess,'visible','off')

gfr=subplot('position',[.15 .15 .9 .9]);
ax=[-1 1 -1 1];
axis(ax);axis(axis);axis('square');axis('off');hold on
plot(v(1),v(2),'ko')
text(.3,.5,'Koch Fractal','color','red',...
           'fontsize',16,'fontweight','bold')
drawnow
onecount=0;
for j = 1:k
    val=rand;
    if val<=.25
       v=eval(T1);
    end
    if val>.25 & val<=.5
       v=eval(T2);
    end
    if val>.5 & val<=.75
       v=eval(T3);
    end
    if val>.75 & val<=1
       v=eval(T4);
    end
    plot(v(1),v(2),'k.','markersize',6)
    drawnow
end
set(mess,'visible','on')
clc,disp('kochifs routine is over.')
disp('To delete all figures currently available type close all.')
disp('To delete only the last figure generated type close gcf.')
