function p=paracub(Q,R,Qd,Rd)  %3/5/99;  6/24/2015
%paracub    Demo of cubic curves defined parametrically.
%           The input consists of a pair of points and the parametric
%           derivative at these points. (The parametric derivatives control
%           the shape of the cubic polynomial through the points.)
%
%           Use in the form   ==> paracub(Q,R,Qd,Rd);<== Note the semicolon
%                        or   ==> p = paracub(Q,R,Qd,Rd);<== semicolon
%                        In this form p contains the set of points that is
%                        in the graph. (Qd and Rd are used to denote the
%                        derivative vectors at Q and R respectively.
%
%           The inputs are 3-vectors for a 3D cubic curve or all 2-vectors
%           for a 2D cubic curve. 
%      
%           Input:    Q - the coordinates of one point
%                     R - the coordinates of a second point
%                     Qd - the parametric derivative at point Q
%                     Rd- the parametric derivative at point R
%
%           Output:   A graph of the segment of the curve starting at point
%                     Q and going to point R. The points on the curve are
%                     generated from a linear combination of Q, R, Qd, and Rd.
%                     This is often referred to as the geometric form of cubic.
%
%       David R. Hill, MATH Dept, Temple University
%       Philadelphia, Pa  19122  Email: dhill001@temple.edu

%This a form of local Hermite interpolation if executed on sets of points.
%
u=0:.01:1;%values of the parameters
c=[2 -3 0 1;-2 3 0 0;1 -2 1 0;1 -1 0 0]; %coefficients of the polynomials
%                                        that multiply Q, R, Qd, and Rd
%
%The coefficients of the cubic polynomial in parameter u for the information
%in Q, R, Qd and Rd
%The parametric expression is
%(2u^3 -3u^2 + 1)*Q + (-2u^3 + 3u^2)*R +(u^3 - 2u^2 + u)*Qd + (u^3 -u^2)*Rd
%
Q=Q(:);R=R(:);Qd=Qd(:);Rd=Rd(:); %making inputs columns
k=length(R);
D=[Q R Qd Rd];
coeff=[polyval(c(1,:),u);polyval(c(2,:),u);polyval(c(3,:),u);polyval(c(4,:),u)];
p=D*coeff;%compute the coordinates of the points from Q to R
figure
if k==3 %3D case
   plot3(p(1,:),p(2,:),p(3,:),'r-','linewidth',2)
   text(Q(1),Q(2),Q(3),'Q','fontweight','bold')
   text(R(1),R(2),R(3),'R','fontweight','bold')
end
if k==2 %2D case
   plot(p(1,:),p(2,:),'r-','linewidth',2)
   text(Q(1),Q(2),'Q','fontweight','bold')
   text(R(1),R(2),'R','fontweight','bold')
end
