function pintdemo   %11/16/97  6/24/2015
%PINTDEMO  A demo of interpolants to a data set of
%          3 points. The three 'basis' functions are displayed and 
%          added point by point.
%
%          Demo tool for linear combinations of interpolants.
%          The ordered pairs used are: (1,4), (2,-3), (3,5)
%
%          Use in the form   ==> pintdemo <==
%
%  By: David R. Hill, Mathematics Dept., Temple Univ.
%      Philadelphia, PA. 19122    Email: dhill001@temple.edu

x=[1 2 3];y=[4 -3 5]; %the data
rval=[1 3 -5 5]; %DOMAIN & RANGE
ID=eye(3); %3 by 3 identity whose columns
           %are the y-coordinates of the basis polynomials

bkgr='white'; %background color

f0='(t-x(2))*(t-x(3))/((x(1)-x(2))*(x(1)-x(3)))';
f1='(t-x(1))*(t-x(3))/((x(2)-x(1))*(x(2)-x(3)))';
f2='(t-x(1))*(t-x(2))/((x(3)-x(1))*(x(3)-x(2)))';
t=1:.05:3;
vf0=vectorize(f0);vf1=vectorize(f1);vf2=vectorize(f2);
y0=eval(vf0);y1=eval(vf1);y2=eval(vf2);
hfig=figure('unit','normal','position',[0 0 1 1]);
%vanity
vanbox=subplot('position',[.05 .05 .1 .06]);axis('off');
text(0,0,'by D.R.Hill','color','black','fontsize',12,...
     'fontweight','bold','fontangle','oblique')

sb1=subplot(221);axis(rval),axis(axis)
hold on
plot(t,y0,'-r',x,y,'om',x,y,'xm',t,zeros(size(t)),'-k','linewidth',2)
set(sb1,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sb1,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
plot(x,ID(1,:),'or',x,ID(1,:),'+r','linewidth',2)
title('P1(x)','fontsize',14,'fontweight','bold'),pause(3)
hold off

sb2=subplot(222);axis(rval),axis(axis)
hold on
plot(t,y1,'-g',x,y,'om',x,y,'xm',t,zeros(size(t)),'-k','linewidth',2)
set(sb2,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sb2,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
plot(x,ID(2,:),'og',x,ID(2,:),'+g','linewidth',2)
title('P2(x)','fontsize',14,'fontweight','bold'),pause(3)
hold off

sb3=subplot(223);axis(rval),axis(axis)
hold on
plot(t,y2,'-b',x,y,'om',x,y,'xm',t,zeros(size(t)),'-k','linewidth',2)
set(sb3,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sb3,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
plot(x,ID(3,:),'ob',x,ID(3,:),'+b','linewidth',2)
title('P3(x)','fontsize',14,'fontweight','bold'),pause(3)
hold off

sb4=subplot(224);axis(rval),axis(axis)
hold on
plot(t,y(1)*y0,'-r',t,y(2)*y1,'-g',t,y(3)*y2,'-b',...
x,y,'om',x,y,'xm',t,zeros(size(t)),'-k','linewidth',2)
set(sb4,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sb4,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
title('y(i)*Pi(x): i=1,2,3','fontsize',14,'fontweight','bold')
xlabel('Press Enter to Continue.','fontsize',14,'fontweight','bold')
hold off
pause

close(hfig)

%SECOND SET OF GRAPHS
hfig=figure('unit','normal','position',[0 0 1 1]);

%vanity
vanbox=subplot('position',[.05 .05 .1 .06]);axis('off');
text(0,0,'by D.R.Hill','color','black','fontsize',12,...
     'fontweight','bold','fontangle','oblique')

sbt=subplot(211);axis(rval),axis(axis)
hold on
plot(t,y(1)*y0,'-r',t,y(2)*y1,'-g',t,y(3)*y2,'-b',x,y,'om',x,y,'xm',...
t,zeros(size(t)),'-k','linewidth',2)
set(sbt,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sbt,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
title('y(i)*Pi(x): i=1,2,3','fontsize',14,'fontweight','bold')
pause(4)
hold off

sbb=subplot(212);axis(rval),axis(axis)
hold on
plot(x,y,'om',x,y,'xm','linewidth',2)
set(sbb,'xcolor',[0 0 0],'ycolor',[0 0 0]);
set(sbb,'xtick',[rval(1):.2:rval(2)],'ytick',[rval(3):rval(4)],...
    'xgrid','on','ygrid','on');
hold off

title('Adding the curves above point-by-point.','fontsize',14,'fontweight','bold')
for jj=1:length(t)
    subplot(211)
    hold on
    plot([t(jj) t(jj)],[-5 5],'-k','linewidth',2)
    drawnow
    hold off
    subplot(212)
    hold on
    plot(t(jj),y(1)*y0(jj)+y(2)*y1(jj)+y(3)*y2(jj),...
        '+k','linewidth',2)
    drawnow
    hold off
    svd(rand(50)); %timer delay
end
pause(2)
title('4*P1(x) - 3*P2(x) + 5*P3(x)','fontsize',14,'fontweight','bold')
xlabel('Press Enter to Continue.','fontsize',14,'fontweight','bold')
%pause
clc,disp('PINTDEMO is over!')


