%           << updated 10/20/98;  6/24/2015;
%PINTERP   The polynomial interpolant to a set of ordered
%          pairs is computed. You can request a table of
%          coefficients for the polynomial and a sketch.
%          After a sketch is generated there are options
%          for changing the graphics window, evaluating the 
%          polynomial model, and superimposing a function graph.
%          A maximum of 26 points can be used. 
%          The coefficients of the interpolating polynomial
%          are returned in vector coeff.
%
%          (Routines interpit, divdiff and vectorize are used.)
%
%   Use in the form   ===>  pinterp  <===
%   
%   By: David R. Hill, Math Dept, Temple University,
%       Philadelphia, Pa. 19122   Email: dhill001@temple.edu

num=['25';'24';'23';'22';'21';'20';'19';'18';'17';'16';'15'];
num=[num ;'14';'13';'12';'11';'10';' 9';' 8';' 7';' 6';' 5'];
num=[num ;' 4';' 3';' 2';' 1';' 0'];
bkgr='white';
N=100; %number of points to use for the graph
sigfigerr='N';
head='      <<<  Polynomial Interpolation with Plotting  >>>';

s0=' ';
s1='Press Enter to continue.';
s2=...
'Enter your function as a formula in variable x .';
s3='Your choice ==> ';
s7='           ** Choose a display window for your graph. **';

menu=['   1. Use all of the domain of definition and entire range.';
      '                                                           ';
      '   2. Use all of the domain of definition, but             ';
      '          enter a new range.                               ';
      '                                                           ';
      '   3. Enter a subset of the domain, but                    ';
      '          keep the entire range.                           ';
      '                                                           ';
      '   4. Enter both an x and y spread for graphing.           ';
      '                                                           ';
      '   0. Quit.                                                '];

menu1=['   1. Choose a different graphing window.   ';
       '                                            ';
       '   2. Show the current graph.               ';
       '         Option for a grid.                 ';
       '                                            ';
       '   3. Superimpose the graph of a function   ';
       '      and display the error.                ';
       '                                            ';
       '   4. Evaluate the polynomial at points.    ';
       '                                            ';
       '   0. Quit.                                 '];

menu2=['                DATA Input                           ';
       '                                                     ';
       '   1. Type in a vector of x-coordinates and          ';
       '              a vector of y-coordinates.             ';
       '                                                     ';
       '   2. Enter the name of a vector containing the      ';
       '      x-coordinates and the name for a vector        ';
       '      containing the y-coordinates.                  ';
       '                                                     ';
       '   3. Use the mouse to choose a set of ordered pairs.';
       '                                                     ';
       '   0. QUIT!                                          ';
       '                                                     ';
       '<< RESTRICTION: at most 26 ordered pairs permitted.>>']; 

menu3=['   1. See the table of values in a short format.';
       '                                                ';
       '   2. See the table of values in a long format. ';
       '                                                ';
       '   3. Save the table of values as a disk file.  ';
       '                                                ';
       '   0. Return to previous menu.                  '];

menu4=['           OPTIONS                                 ';
       '                                                   ';
       '   1. See the formula the polynomial model.        ';
       '                                                   ';
       '   2. Graph the polynomial model.                  ';
       '                                                   ';
       '   3. Evaluate the polynomial model.               ';
       '                                                   ';
       '   0. QUIT! (The coefficient will be               ';
       '              in vector coeff.)                    '];
 
gmenu=['                                               ';
       '                                               ';
       '        1. Show graph with a grid.             ';
       '                                               ';
       '        2. Show graph without a grid.          ';
       '                                               '];
%=======================================================================
%STARTING MAIN ROUTINE
%

%initializing the vector of coefficients
c=[];
clc,disp(head),disp(s0)
   gooddata='N';
   while gooddata=='N'
      disp(menu2),disp(s0),dch=input(s3);
      if isempty(dch),dch=pi;end
      if dch==1
         disp(s0),disp('Enter your x-values between square backets like [2, 4.1, 5.2].')
         xdat=input('x-coordinates =  ');n=length(xdat);
         disp(s0),disp('Enter your y-values between square backets like [0, -2.1, 3.4].')
         ydat=input('y-coordinates =  ');m=length(ydat);
         if n~=m
            disp('Coordinate vectors must have the same number of entries.')
            disp('Press Enter to try again.')
            pause
         else
            gooddata='Y';
         end
      end
      if dch==2
         disp(s0),disp('Enter the name of a vector containing the x-values.')
         xdat=input('Vector for the x-coordinates is  ');n=length(xdat);
         disp(s0),disp('Enter the name of a vector containing the y-values.')
         ydat=input('Vector for the y-coordinates is  ');m=length(ydat);
         if n~=m
            disp('Coordinate vectors must have the same number of entries.')
            disp('Press Enter to try again.')
            pause
         else
            gooddata='Y';
         end
      end
      if dch==3,gooddata='Y';clc,help interpit,disp(s1),pause
         interpit  
         return
      end
      if dch==0,clc,disp(s0),disp('Routine pinterp is over.')
         return
      end
      if (dch~=0 & dch~=1 & dch~=2)
         disp('Improper choice.'),disp(s1),pause
      end
   end %while gooddata

if n>26
   disp('More than 26 data points. This routine has its')
   disp('labeling set up for 26 or fewer points.')
   disp('*****  PINTERP terminated.  *****')
   m=0;
end
while n == m
   nm1=n-1;
   M=eye(n);
   for i =2:n
      M(i,1)=-xdat(i-1)*M(i-1,1);
      for j=2:i-1
         M(i,j) = -xdat(i-1)*M(i-1,j)+M(i-1,j-1);
      end
   end
   c=divdiff(xdat,ydat);%top row has div-diff coefficients
   c=c(1,2:n+1); %starting in col. 2
   for i=1:n,M(i,:)=c(i)*M(i,:);end
   c=sum(M);
   newc=[];
   for i=1:n,newc(i)=c(n+1-i);end,c=newc;
   coeff=c; %storing the coefficients so they can be accessed
            %upon termination
   
   goodch='N';
   while goodch=='N'
      clc,disp(head),disp(s0),disp(menu4),disp(s0),doch=input(s3);
      if isempty(doch),doch=pi;end
      if doch==0,clc,disp(s0),disp('Routine pinterp is over.')
         disp('Polynomial coefficients are in vector coeff.')
         return
      end
      if doch==1
         clc,disp(head),disp(s0)
         disp('The interpolating polynomial is:')
         [lnum,lcnum]=size(num);
         jstart=lnum-nm1;
         for j= jstart:1:lnum
             if c(j+1-jstart)>=0,sgn=' + ';else;sgn=' - ';end
             st=[sgn num2str(abs(c(j+1-jstart))) ' * x^' num(j,:)];
             disp(st)
         end
         disp(s0),disp(s1),pause
       end
       if doch==2
          clc,disp(head),disp(s0),
          disp('Enter interval [a,b] to sketch over')       
          a=input('left end a = ');b=input('right end b = ');       
          disp(s0)       
          h=(b-a)/N;  %N points used to sketch polynomial
          xp=a:h:b;yp=polyval(c,xp); %compute pairs for graph
  %------------------------------------------------------------------   
  %OPTIONS for display window, superimposing a function & evaluating |
  %------------------------------------------------------------------
          window='N';hfigflag='N';gstate='N';
          while window == 'N'
             clc,disp(head),disp(s0),disp(setstr('*'*ones(1,50)))
             disp(['The polynomial is evaluated over [' num2str(a) ',' num2str(b) ']']);
             disp(s0), ysmall=min(yp);ylarge=max(yp); 
             disp(['The range is from ' num2str(ysmall) ' to ' num2str(ylarge)])
             disp(s0),disp('Choose a graphing window:'),disp(s0)
             disp(menu),disp(s0),ch=input(s3);
             if isempty(ch),ch=pi;end
             if ch==0
                disp('Polynomial coefficients are in vector coeff.')
                return
             end
             if ch==1,xs=a;xl=b;ys=ysmall;yl=ylarge;end
             if ch==2,xs=a;xl=b;
             ys=input('Smallest y to use = ');
             yl=input('Largest y to use = ');
          end
          if ch==3,ys=ysmall;yl=ylarge;
             xs=input('Smallest x to use = ');
             xl=input('Largest x to use = ');
          end
          if ch==4
             xs=input('Smallest x to use = ');
             xl=input('Largest x to use = ');
             ys=input('Smallest y to use = ');
             yl=input('Largest y to use = ');
          end
          if ch==1 | ch==2 | ch==3 | ch==4
             if hfigflag=='Y';delete(hfig);gstate='N';end
             hfig=figure('units','normal','position',[0 0 1 .9],'color',bkgr);
             hfigflag='Y';
             figsub=subplot('position',[.1,.15,.8,.75]);
             axis([xs xl ys yl])
             axis(axis)
             hold on
             plot(xdat,ydat,'*r','markersize',10)
             %recompute points for the graph
             xp=xs:h:xl;yp=polyval(c,xp);
             plot(xp,yp,'.b','markersize',5)
             lgd=['original data *   interpolating polynomial is dotted '];  
             title(lgd)  
             mfigsub=subplot('position',[.05,.03,.4,.06]);
             axis('off')
             text(0,1,s1,'color','black')
             pause;  %****
             set(hfig,'visible','off');
             hold off
             skwindow='N';
             while skwindow=='N'
                clc,disp(head),disp(s0),disp(menu1);ch=input(s3);
                if isempty(ch),ch=pi;end
                if ch==1, skwindow='Y';end
                if ch==2
                   gchoice='N';
                   while gchoice=='N'
                      disp(gmenu),gch=input(s3);
                      if isempty(gch),gch=pi;end
                      if gch==1,gchoice='Y';subplot(figsub),grid on;
                         set(hfig,'visible','on');
                         pause;
                         set(hfig,'visible','off');
                         %figure(gcf)
                      end
                      if gch==2,gchoice='Y';subplot(figsub),grid off;
                         set(hfig,'visible','on');
                         pause;
                         set(hfig,'visible','off');
                         %figure(gcf)
                      end
                   end
                end
                if ch==3
                   disp(s2),disp(s0),f=input('f(x) = ','s');
                   hold on
                   %in case there is something in x it is not destroyed
                   sigx=0;if exist('x'),sigx=1;xtemp=x;end
                   x=xp;fv=vectorize(f);fy=eval(fv);
                   if sigx==1,x=xtemp;end
                   set(hfig,'visible','on');
                   %figure(gcf)
                   subplot(figsub)
                   plot(xp,fy,'-g','linewidth',2),hold off
                   pause;
                   set(hfig,'visible','off');
                   hfigerr=figure('units','normal','position',[0 0 1 .9],'color',bkgr);
                   sigfigerr='Y';
                   grafc=subplot('position',[.1,.15,.4,.75]);
                   axis([xs xl ys yl])
                   axis(axis)
                   hold on
                   plot(xdat,ydat,'*r','markersize',10)
                   %recompute points for the graph
                   xp=xs:h:xl;yp=polyval(c,xp);
                   plot(xp,yp,'.b','markersize',5)
                   plot(xp,fy,'-g','linewidth',2)
                   lgd=['Comparison.'];  
                   title(lgd)
                   hold off
                   grafe=subplot('position',[.53,.15,.4,.75]);
                   plot(xp,fy-yp,'-r','linewidth',2)
                   title('  ERROR: True - Approx.')
                   xlabel(s1),hold off
                   %messsub=subplot('position',[.05,.05,.4,.08]);
                   %axis('off')
                   %text(1,1,s1,'color','black')
                   pause
                   set(hfigerr,'visible','off')
                end
                if ch==4
                   disp('Enter a vector of values between square brackets.')
                   t=input('values = ');t=t(:);valt=polyval(c,t);
                   valtab=[t valt(:)];
                   speval1='N';
                   while speval1=='N'
                      clc,disp(head),disp(s0),disp(menu3)
                      vch=input(s3);disp(s0) 
                      if isempty(vch),vch=pi;end 
                      if vch==0,speval1='Y';end
                      if vch==1 | vch==2
                         if vch==1
                            format short e
                         else
                            format long e
                         end
                         disp(valtab),format short,disp(s1),pause
                      end
                      if vch==3
                         name=input('Enter a name for the table: ','s');
                         eval(['save ' name ' valtab'])
                         disp(['Saved as file ' name ' in variable valtab.'])
                         disp(s1),pause
                      end
                   end %while speval1
                end
                if ch==0
                   disp('Polynomial coefficients are in vector coeff.')
                   disp('Press ENTER to see final figures.')
                   pause
                   set(hfig,'visible','on')
                   pause(1)
                   if sigfigerr=='Y';set(hfigerr,'visible','on');end
                   return
                end
             end % skwindow 
         end
      end %end of sketching window loop
      clc,disp(s0),disp('Routine pinterp is over!') 
      end %doch==2
                if doch==3
                   disp('Enter a vector of values between square brackets.')
                   t=input('values = ');t=t(:);valt=polyval(c,t);
                   valtab=[t valt(:)];
                   speval1='N';
                   while speval1=='N'
                      clc,disp(head),disp(s0),disp(menu3)
                      vch=input(s3);disp(s0) 
                      if isempty(vch),vch=pi;end 
                      if vch==0,speval1='Y';end
                      if vch==1 | vch==2
                         if vch==1
                            format short e
                         else
                            format long e
                         end
                         disp(valtab),format short,disp(s1),pause
                      end
                      if vch==3
                         name=input('Enter a name for the table: ','s');
                         eval(['save ' name ' valtab'])
                         disp(['Saved as file ' name ' in variable valtab.'])
                         disp(s1),pause
                      end
                   end %while speval1
                end
      
   end %while goodch
   m=n-1;  %to terminate while loop
end   %end of while n==m
