%          <<updated 9/15/98;  6/25/2015
%PMDEMO2  Graphical demonstration of convergence of approximate
%         eigenvectors generated by the scaled power method.
%         The matrix A is assumed to be 2x2 and real.
%         The column u is an initial guess for an eigenvector
%         associated with the dominant eigenvalue of A.
%         Sets of four approximate eigenvectors are plotted on
%         the same set of axes.
%
%  Use in the form  ===>  pmdemo2  <===
%                 
%  There are built-in demos available or you can enter your own
%  data matrix A and vector u.
%
%  Uses utility mat2strh
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%strings
s0=' ';
s1='Your choice --> ';
cont='Press ENTER to continue.';
head=[blanks(30) 'PMDEMO2'];
head1=['A graphical demonstration of the power method. For a 2 by 2    ';
       'matrix A and an initial guess for an eigenvector u we compute  ';
       'vectors           Au, (A^2)u, (A^3)u, ...                      ';
       'This sequence of vectors is displayed both algebraically and   ';
       'graphically, hence the behavior of the approximations is shown.';
       'The vectors displayed will be scaled to be unit vectors. This  ';
       'makes the graphics easier to display and does not affect the   ';
       'behavior of the sequence since any nonzero scalar multiple of  ';
       'an eigenvector is another eigenvector.                         ';
       '                                                               ';
       'Follow the directions displayed.                               '];
menu=['<1> Continue with power method.';
      '                               ';
      '<0> Quit.                      '];

menu1=['<1> Enter matrix A and initial guess u for an eigenvector.';
       '                                                          ';
       '<2> Choose a built-in demo matrix A and vector u.         ';
       '                                                          ';
       '<0> Quit.                                                 '];

demodata=['Choice #1       Choice #2     Choice #3      Choice #4 ';
          '                                                       ';
          '    3   1           5   1         1   2          0   1 ';
          'A =             A =           A =            A =       ';
          '    2   1           0   2        -4   3          1   0 ';
          '                                                       ';
          '    1               -1            1               1    ';
          'u =             u =           u =            u =       ';
          '    2                1            1              -2    '];

clrs=['bbggmmcc']; %colors  blue green magenta cyan
                   %initial vector shown in red

n=4; %number of iterations shown each time;
     % make sure n is even because of way data is stored
     % origin for each vector included in data matrix

%things that are evaled
act1='B=[];for k=1:n,v=A*u;val=v./u;u=v/norm(v);B=[B u];end,';
    %n eigenvectors generated by scaled power method
act1=[act1 'if sum(sum(isnan(B)))~=0,'];
act1=[act1 'subplot(messsub),'];
act1=[act1 'ml1=text(.1,.8,''Division by zero has ocurred.'','];
act1=[act1 '''color'',''r'',''fontsize'',14,''fontweight'',''bold'');'];
act1=[act1 'ml2=text(.1,.5,''Try a different initial guess.'','];
act1=[act1 '''color'',''r'',''fontsize'',14,''fontweight'',''bold'');'];
act1=[act1 'ml3=text(.1,.2,''Click the Restart button.'','];
act1=[act1 '''color'',''r'',''fontsize'',14,''fontweight'',''bold'');'];
act1=[act1 'pause,return,end,'];
    %code to trap NaNs ==> division by zero
act1=[act1 'x=zeros(1,2*n);y=zeros(1,2*n);for k=2:2:2*n,'];
act1=[act1 'x(k)=B(1,k/2);y(k)=B(2,k/2);end,'];
   %Separating into x and y components
act1=[act1 'subplot(mainsub);'];
act1=[act1 'axis([-1 1 -1 1]),axis(axis);axis(''square'');'];
act1=[act1 'hold on;'];
act1=[act1 'plot([-1 1],[0 0],''-k'');'];
act1=[act1 'plot([0 0],[-1 1],''-k'');'];
%act1=[act1 'axis([min([u0(1) x]) max([u0(1) x]) '];
%act1=[act1 'min([u0(2) y]) max([u0(2) y])]),axis(axis);axis(''square'');'];

   %DOING the initial vector
act1=[act1 'subplot(infosub),'];
act1=[act1 'text(0,.95,''Scaled Vectors'',''color'',''k'','];
act1=[act1 '''fontweight'',''bold'',''fontsize'',14);'];
act1=[act1 'text(0,.85,''Initial Guess: Vector 0.'',''color'',''k'','];
act1=[act1 '''fontweight'',''bold'',''fontsize'',14);'];
act1=[act1 'u0row=u0'';intvec=mat2strh(u0row,2);'];
act1=[act1 'text(0,.80,intvec,''color'',''r'',''fontweight'','];
act1=[act1 '''bold'',''fontsize'',14'');'];
act1=[act1 'subplot(mainsub);plot([0 u0(1)],[0 u0(2)],''r:'');'];
%act1=[act1 ');']; 
   %the initial guess
act1=[act1 'text(u0(1),u0(2),''0'',''color'',''r'','];
act1=[act1 '''fontweight'',''bold'');'];
act1=[act1 'subplot(messsub);'];
act1=[act1 'ml1=text(.1,.8,''Initial Guess is shown.'','];
act1=[act1 '''color'',''k'',''fontsize'',14,''fontweight'',''bold'');'];
act1=[act1 'ml2=text(.1,.5,''Click in the Message Window, then Press Enter to see approximations.'','];
act1=[act1 '''color'',''k'',''fontsize'',14,''fontweight'',''bold'');'];
act1=[act1 'pause,delete(ml1),delete(ml2),'];
act1=[act1 'ml1=text(.1,.8,''Four new approximations.'','];
act1=[act1 '''color'',''k'',''fontsize'',14,''fontweight'',''bold'');'];
    %*******   PLOT n eigenvectors   ******
act1=[act1 'for k=1:2:2*n,pause(2),subplot(infosub),'];
act1=[act1 'vecname=[''Vector '' num2str(vnum) ''.''];'];
act1=[act1 'text(0,.7-(k-1)*(.1),vecname,''color'',''k'','];
act1=[act1 '''fontweight'',''bold'',''fontsize'',14'];
act1=[act1 ');'];
act1=[act1 'text(0,.7-k*(.1),mat2strh([x(k+1) y(k+1)],2),'];
act1=[act1 '''color'',clrs(k),''fontweight'',''bold'','];
act1=[act1 '''fontsize'',14);'];
act1=[act1 'subplot(mainsub),'];
act1=[act1 'plot(x(k:k+1),y(k:k+1),[clrs(k) ''-'']);'];
act1=[act1 'vn=int2str(vnum);'];
act1=[act1 'text(x(k+1),y(k+1),vn,''color'',clrs(k),'];
act1=[act1 '''fontweight'',''bold'');'];
act1=[act1 'vnum=vnum+1;end'];

act2='subplot(messsub),delete(ml1);';
act2=[act2 'ml1=text(.1,.8,''Click the MORE button, OR'','];
act2=[act2 '''color'',''k'',''fontsize'',14,''fontweight'',''bold'');'];
act2=[act2 'ml2=text(.1,.5,''Click on the QUIT button.'','];
act2=[act2 '''color'',''k'',''fontsize'',14,''fontweight'',''bold'');'];
act2=[act2 'quitbut = uicontrol(''style'',''push'',''units'',''normal'','];
act2=[act2 '''pos'',[.65 .08 .12 .04],''string'',''QUIT'','];
act2=[act2 '''fontweight'',''bold'',''fontsize'',14,''call'','];
act2=[act2 'done);'];
act2=[act2 'morebut = uicontrol(''style'',''push'',''units'',''normal'','];
act2=[act2 '''pos'',[.65 .14 .12 .04],''string'',''MORE'','];
act2=[act2 '''fontweight'',''bold'',''fontsize'',14,''call'','];
act2=[act2 'moreiter);'];

%callbacks  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%for quit button
done='close(gcf),clc,disp(''PMDEMO is over!''),return';

%for more button
moreiter='delete(ml1),delete(ml2),delete(quitbut),delete(morebut),';
moreiter=[moreiter 'subplot(mainsub),cla,'];
moreiter=[moreiter 'subplot(infosub),cla,eval(act1),eval(act2)'];                          

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++   

%data input
typeok='N';
while typeok=='N';
   clc,disp(head),disp(s0),disp(head1),disp(s0)
   disp(menu1)
   disp(s0)
   ch=input(s1);
   if ch==2
      clc,disp(head),disp(s0)
      disp('Demo choices are:'),disp(demodata),disp(s0)
      democh=input(s1);
      if democh~=1 & democh~=2 &democh~=3 & democh~=4
         disp(s0)
         disp('Improper choice. Press ENTER to begin again.')
         pause
      else
         typeok='Y';
      end
      if democh==1,A=[3 1;2 1];u=[1 2]';end
      if democh==2,A=[5 1;0 2];u=[-1 1]';end
      if democh==3,A=[1 2;-4 3];u=[1 1]';end
      if democh==4,A=[0 1;1 0];u=[1 -2]';end      
   end
   if ch==0,clc,disp('PMDEMO is over!'),return,end
   if ch==1
      dataok='N';
      while dataok=='N'
         clc,disp(head),disp(s0)
         disp('Enter a 2 by 2 real matrix A in the form [1 2;3 4]')
         disp(s0)
         A=input('Matrix A = ');
         disp(s0)
         [nA mA]=size(A);
         matsum=sum(sum(A));
         imck=sum(sum(imag(A)));
         if nA~=2 | mA~=2 | imck~=0 | matsum==0
            disp('Matrix must be 2 by 2 with real entries.')
            if matsum==0,disp('Some entries must be nonzero.'),end
               disp(s0),disp(cont),pause
            else
               disp('Enter an inital guess u at an eigenvector.')
               disp('At least on entry must be different from zero.')
               disp('Enter your vector in the form [1 2]'),disp(s0)
               u=input('Vector u =  ');
               u=u(:);
               usum=sum(abs(u));
               if length(u)~=2 | usum==0
                  disp('Vector u must have only 2 entries.')
                  disp('One of the entries must be nonzero.')
                  disp(cont),pause
               else
                  dataok='Y';typeok='Y';
               end
           end
       end
   end
end


choiceok='N';
while choiceok=='N'
   format compact
   clc,disp(head)
   disp('Your matrix is ')
   A
   disp('with initial guess at an eigenvector ')
   u
   disp(s0)
   disp(menu),disp(s0)
   choice=input(s1);
   if choice==0,clc,disp('PMDEMO is over!'),return,end
   if choice~=1
      disp(s0),disp('<><><>Improper choice; try again.')
      disp(cont)
      pause
   else
      choiceok='Y';format
   end
end


%DOING THE GRAPHICS 
%setting graphics window to full size
hfig=figure('units','normal','position',[0 0 1 1]);
axis('off')

%the subplots
titlesub=subplot('position',[.01 .95 .4 .08]);axis('off');
mainsub=subplot('position',[.45 .3 .5 .5]);%axis('off');
vanitysub=subplot('position',[.85 .1 .15 .05]);axis('off');
messsub=subplot('position',[.05 .01 .5 .19]);axis('off');
infosub=subplot('position',[.01 .3 .38 .6]);axis('off');
matsub=subplot('position',[.5 .85 .25 .08]);axis('off');
vecsub=subplot('position',[.8 .85 .1 .08]);axis('off');

%doing title
subplot(titlesub)
text(0,0,'POWER METHOD Demo','color','m','fontweight','bold',...
         'fontsize',20);

%showing matrix A
subplot(matsub)
text(0,.5,'A =','color','r','fontweight','bold',...
         'fontsize',20);
strA=mat2strh(A,3);
text(.2,.9,strA(1,:),'color','r','fontweight','bold',...
         'fontsize',18);
text(.2,0,strA(2,:),'color','r','fontweight','bold',...
         'fontsize',18);

%showing initial vector
subplot(vecsub)
text(0,.5,'u =','color','b','fontweight','bold',...
         'fontsize',20);
uvec=u(:);
stru=mat2strh(uvec);
text(.6,.9,stru(1,:),'color','b','fontweight','bold',...
         'fontsize',18);
text(.6,0,stru(2,:),'color','b','fontweight','bold',...
         'fontsize',18);

%doing vanity
subplot(vanitysub);
text(0,0,'by D.R.Hill','color','black','fontsize',14,'fontweight','bold',...
     'fontangle','oblique')  

%doing message window
subplot(messsub);
plot([0 0 1 1 0],[0 1 1 0 0],'-k','linewidth',2);
axis('off')
title('MESSAGE WINDOW','color','blue','fontsize',14);


%buttons for help/quit/etc
hbutfrm=uicontrol('style','frame','units','normal',...
                 'position',[.84 .12 .14 .11],'backgroundcolor','y');

helpbut = uicontrol('style','push','units','normal','pos',[.85 .18 .12 .04], ...
        'string','HELP','fontweight','bold','fontsize',12,...
        'call','set(gcf,''visible'',''off'');clc,help pmdemo2,disp(cont),pause,set(gcf,''visible'',''on'');');

restbut = uicontrol('style','push','units','normal','pos',[.85 .13 .12 .04], ...
        'string','RESTART','fontweight','bold','fontsize',12,...
        'call','close(gcf),pmdemo');


%the power method iterations
u0=u/norm(u); %original guess; used for plotting later
vnum=1; %initializing vector number to 1

eval(act1)
eval(act2)


