function sierpifs(v,k)  %prev. update 4/10/00  last update 6/23/2015
%SIERPINSKI IFS     Iterated Function System for the Sierpinski Triangle
%             The picture generated is called the Sierpinski Gasket.
%
%             Use in the form  ==> sierpifs(v,k)  <==
%             where
%                   v = [x y] is a point to start the iteration
%                       denoted by o in the picture provided it 
%                       is close enough to the figure. 
%
%                   k = the number of composites to form
%                       
%             If no value of k is specified k = 3000 is used.
%
%             Routine affine is used.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%affine transformation data
A1=(1/2)*eye(2);
A2=A1;
b2=[1 0]';
A3=A1;
b3=[0.5 0.5]';

%the transformations
T1='affine(A1,[0 0],v)';
T2='affine(A2,b2,v)';
T3='affine(A3,b3,v)';

if nargin==1,k=3000;,end
hfig=figure('units','normal','position',[0 0 1 1],'color','white');
axis('off')

%tag=subplot('position',[.05 3 .08 .08]);
%axis('off')
%mess=text(.05,.05,'Routine is over. Press ENTER.');
%set(mess,'visible','off')

gfr=subplot('position',[.15 .15 .8 .8]);
ax=[0 2 0 1];
axis(ax);axis(axis);axis('square');hold on

v=v(:);
plot(v(1),v(2),'ko')
drawnow

for j = 1:k
    val=rand;
    if val<=1/3
       v=eval(T1);
    end
    if val>1/3 & val<=2/3
       v=eval(T2);
    end
    if val>2/3 & val<=1
       v=eval(T3);
    end
    plot(v(1,:),v(2,:),'k.','markersize',6)
    drawnow
    if j==1
       title('Sierpinski Gasket','color','red','fontweight','bold','fontsize',14)
            
    end
end
xlabel('Routine is over. Press ENTER.','fontsize',14,'fontweight','bold')
%subplot(tag)
%set(mess,'visible','on')

clc,disp('seirpifs routine is over.')
disp('To delete all figures currently available type close all.')
disp('To delete only the last figure generated type close gcf.')
