function sierptri(p)   %prev. update 7/3/98 last update 6/23/2015
%SIERPINSKI Triangle is generated using p steps.
%           This is an instructional file to show a few steps and then
%           ask for descriptions of succeeding steps to emphasize
%           self similarity.
%
%             Use in the form  ==> sierptri(p)  <==
%             where
%                   p = the number of steps
%                       
%             Routine affine is used.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%affine transformation data
A1=(1/2)*eye(2);
A2=A1;
b2=[1 0]';origb2=b2;
A3=A1;
b3=[1/2 sqrt(3)/2]';origb3=b3;

%Starting triangle; equilateral 
triv=[0 0;2 0;1 sqrt(3);0 0]';

%the transformations
T1='affine(A1,[0 0],v)';
B2='b2=[abs(.5*(v(1,1)-v(1,2))); 0]';
T2='affine(A2,b2,v)';
B3='b3=[abs(.25*(v(1,1)-v(1,2))) ;sqrt(3)/2^(k+1)]';
T3='affine(A3,b3,v)';

%
%The graphics
ax=2*[0 1 0 1];
figure
axis(ax);axis(axis);axis('square');hold on
plot(triv(1,:),triv(2,:),'k-')
fill(triv(1,:),triv(2,:),'k')
title(['The SIERPINSKI Triangle.'],'color','r','fontweight','bold','fontsize',16)
xlabel(['The start; level zero. PRESS ENTER to continue.'],'fontweight','bold')
pause
xlabel(' ')
v=triv;
%
%LEVEL 1
%
v1=eval(T1);
v2=eval(T2);
v3=eval(T3);  
fill(triv(1,:),triv(2,:),'w')
plot(v1(1,:),v1(2,:),'k-')
plot(v2(1,:),v2(2,:),'k-')
plot(v3(1,:),v3(2,:),'k-')
fill(v1(1,:),v1(2,:),'k')
fill(v2(1,:),v2(2,:),'k')
fill(v3(1,:),v3(2,:),'k')
drawnow

   xlabel(['The first step; Level one. PRESS ENTER to continue.'],'fontweight','bold')
   pause
if p==1
   xlabel(['The routine is over; PRESS ENTER.'],'fontweight','bold')
   return
end
xlabel(' ')

oldS=[v1 v2 v3]; %Coordinates of three major triangles

%loop for levels 2 thru p
%NOTE: after p = 2, the refinements are only shown in the lower left
%      triangle
for k=2:p
    [m,n]=size(oldS);
    newS=[];
    b2=.5*b2;b3=.5*b3; %scaling the shifts within first triangle
    v=oldS(:,1:4);
    fill(v(1,:),v(2,:),'w')
    %establishing the base
    v1=eval(T1);
    v2=eval(T2);
    v3=eval(T3);
    newS=[v1 v2 v3];
    %plotting the base
    plot(v1(1,:),v1(2,:),'k-')
    plot(v2(1,:),v2(2,:),'k-')
    plot(v3(1,:),v3(2,:),'k-')
    fill(v1(1,:),v1(2,:),'k')
    fill(v2(1,:),v2(2,:),'k')
    fill(v3(1,:),v3(2,:),'k')
    drawnow
    if k==2 
       %translating the base to the other regions
       for j=5:4:12
           if j==5,c=origb2;end
           if j==9,c=origb3;end
           fill(oldS(1,j:j+3),oldS(2,j:j+3),'w')
           v1=affine(eye(2),c,v1);
           v2=affine(eye(2),c,v2);
           v3=affine(eye(2),c,v3);
           newS=[newS v1 v2 v3];
           plot(v1(1,:),v1(2,:),'k-')
           plot(v3(1,:),v3(2,:),'k-')
           fill(v1(1,:),v1(2,:),'k')
           fill(v2(1,:),v2(2,:),'k')
           fill(v3(1,:),v3(2,:),'k')
           drawnow    
           %re-establishing the base 
           v1=eval(T1);
           v2=eval(T2);
           v3=eval(T3);
       end
   end 
   xlabel(['Level ', num2str(k), '. PRESS ENTER to continue.'],'fontweight','bold')
   pause
   oldS=newS;
end
xlabel(['The routine is over; PRESS ENTER.'],'fontsize',14,'fontweight','bold')


%NOTES for future changes
% loops if n>12 for the other portions of things
     %one loop for the parts of the first triangle, if any
     %another for translation by [1 0]'
     %yet another for translation by [1/2 sqrt(3)/2]'
     %the divisions are based on powers of 3