function [npic,opic,ev]=specgen(A)     %last updated 11/16/01
%SPECGEN  Generate lower rank approximations to a figure
%         using spectral decomposition of a digitized
%         image of the figure which is contained in A. Upon
%         return 
%               npic   contains the last approximation generated
%               opic   contains the original picture
%               ev     contains the number of eigenvalues values
%                      used to construct npic  
%          (routine scan is required)
%
%    Use in the form   -->  [npic,opic,eval]=specgen(A)  <--
%
%   By: David R. Hill, MATH Dept, Temple University,
%       Philadelphia, Pa., 19122  Email: dhill001@temple.edu
status1='IMAGE constructed with ';
status2=' eigenvalue(s).';
head=[blanks(25) 'IMAGE GENERATOR'];
s0=' ';
done='All eigenvalues values have been used. ';
done=[done 'Image generation is over.'];
menu=['1.  Update image using next eigenvalue value.';
      '0.  QUIT                                     '];
select='  ENTER your choice  -->  ';
chagain='Incorrect choice--TRY AGAIN.';
opic=scan(A);
[m,n]=size(A);
if m~=n
   disp('Error: Input matrix not square.')
   disp('Routine is over!')
   return
end
if sum(sum(abs(A-A')))~=0
   disp('Error: Matrix not symmetric.')
   disp('Routine is over!')
   return
end
[V,D]=eig(A);
V=gschmidt(V);
p=[1:n];
d=diag(D)';q=[d;p];
for i=1:n-1
   swtch='N';
   mx=abs(q(1,i));pt=q(2,i);
      for j=i+1:n
         if abs(q(1,j))>mx
            mx=abs(q(1,j));pt=j;
            swtch='Y';  %indicates need to interchange
         end
      end
   if swtch=='Y'
      temp=q(:,i);
      q(:,i)=q(:,pt);
      q(:,pt)=temp;
   end
end
ds=q(1,:);order=q(2,:);
VS=V(:,order);
B=zeros(size(A));
B=B+VS(:,1)*VS(:,1)'*ds(1);
cpic=scan(B);npic=cpic;

sp=[' '*ones(1,m);' '*ones(1,m);' '*ones(1,m)]';
%sp=['*'*ones(1,m);'*'*ones(1,m)]';
sp=char(sp);%sp=setstr(sp);
sval=1;sw=1;
while sw==1
   clc,disp(head),disp(s0),st=[status1 int2str(sval) status2];
   %disp(st),disp([opic sp cpic sp npic]),disp(s0)
   %Now the original picture is not shown.
   disp(st)
   disp(['PREVIOUS' blanks(n+6-8) 'CURRENT'])
   disp(['  IMAGE ' blanks(n+6-8) '  IMAGE'])
   disp(s0)
   disp([sp cpic sp npic]),disp(s0)
   disp(menu),disp(s0)
   ch=input(select);
   if isempty(ch),ch=999;end
   if ch==0,return,end
   if ch~=1
      disp(chagain),pause(3)
   else
      sval=sval+1;
      if sval <= n
         B=B+ds(sval)*VS(:,sval)*VS(:,sval)';
         cpic=npic;npic=scan(B);
      else
         sval=n;sw=2;
      end
   end
end
disp(done)
