function tree3(p,rfactor) %prev. updated 7/28/98  last 6/23/2015
%TREE3    Draws the ternary tree fractal 
%                  for p steps using a reduction factor.
%
%        Use in the form  ==>  tree3(p,rfactor)  <==
%
%        p an integer between 0 and 7
%        (Because a matrix is used to keep track of points at
%         which thingsare drawn, the case p = 8 exceeds
%         Student Edition array size limitation.)
%
%        rfactor in (0,.48)
%        (For factors > .48 the braches will over lap.)
%        
%        Draw a the line segment from (0,0) to (1,0); call it L.
%        To this figure adjoin two additional line segments of 
%        the same length. The first is that obtained from L 
%        by rotating it about the origin 120 counterclockwise 
%        and the second is obtained from L by rotating it about 
%        the origin 240 counterclockwise. Call the resulting 
%        figure a tripod. Scale the tripod down by a factor 
%        of a r<.48 and the translate it so that the origin 
%        of the scaled down figure is at the end of the original 
%        "tripod". Repeat the scaling and translating, drawing 
%        the figure at each stage.
%
%        Uses m-file affine to perform the scaling and translation.
%
%  By: David R. Hill, MATH Department, Temple University
%      Philadelphia, Pa., 19122        Email: dhill001@temple.edu

%For an alternate approach see
%         Fractals, Endlessly Repeated Geometric Figures
%                by   Hans Lauwerier
%                     Princeton University Press, 1991
%                     ISBN 0-691-02445-6

if p<0 | fix(p)~=p
   disp('Error: Input value of p must be a positive integer.')
   return
end
if rfactor<=0 | rfactor>=.48 
   disp('Error: Input value of rfactor must be between 0 and 0.48 .')
   return
end

gcode='N';
while gcode=='N'
   clc
   if p >= 8
      disp(['Warning: Lots of line segments will be drawn.'])
      disp('This may require a lot of time.')
      %disp('In the Student Edition the array size limitation will be exceeded.')
      disp(' ')
      val=input('Press 0 to quit; press 1 to continue.');
      if val==0,return,end
      if val==1,gcode='Y';end
   else
      gcode='Y';
   end
end %while

rfactor=.45; %reduction factor
graf='plot(P1(1,:),P1(2,:),clr,P2(1,:),P2(2,:),clr,P3(1,:),P3(2,:),clr)';
scale=rfactor*eye(2);
D =[0 1;0 0]; %Original line segment L
R=[cos(2*pi/3) -sin(2*pi/3);sin(2*pi/3) cos(2*pi/3)];
D1=R*D; %the other two legs of the tripod
D2=R*D1;

%the graphics
figure
ax=[-2 2 -2 2];axis(ax);axis(axis);axis('square');hold on

S=[D D1 D2]; %Original tripod

P1=S(:,1:2);P2=S(:,3:4);P3=S(:,5:6);
clr='-k';
eval(graf) %graph original
title(['TERNARY TREE'],'color','r','fontsize',14,'fontweight','bold')
drawnow
oldns=S(:,[2 4 6]);
for k=1:p
    nam=xlabel(['Level ' num2str(k)]);
    newns=[];
    for j=1:3^k
        clr='k-';
        tempns=affine(scale^k,oldns(:,j),S);
        P1=tempns(:,1:2);
        P2=tempns(:,3:4);
        P3=tempns(:,5:6);
        if k==1,clr='b-';end
        if k==2,clr='r-';end
        if k==3,clr='g-';end
        if k==4,clr='m-';end
        eval(graf)
        drawnow
        newns=[newns tempns(:,[2 4 6])];
    end
    oldns=newns;
    pause(8)
end
xlabel(['Routine is over. Press ENTER'],'fontsize',14,'fontweight','bold')