            %previous update  4/4/00  last update 6/21/2015
%VIZPLANE   Visualizing the intersections of planes.
%           There are five demos available. You will see the graphs of
%           three planes one at a time and then the picture with the three
%           planes on the same set of axes. You will then be asked to press
%           Enter which will show the three planes in a larger window. There
%           will appear a button to change the view of the picture. The views
%           change by clicking on the 'Next View' button as though you were
%           moving around the z-axis. 
%
%           Use algebra to find the case for the solution set of the three 
%           equations of the planes and then change your view until you can 
%           "see" the solution set.
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%initializing a counter for later use
j = 0;

%strings
header='VIZPLANE';
cont='Press ENTER to continue.';
s0=' ';
choice='   Make your choice:  ==>  ';
menu=['There are 5 demos available.    ';
      'Choose 1 - 5 or 0 to quit.      ';
      '                                '];


%call backs
%doquit='close(''all''),clc,disp(''VIZPLANE is over!'')';
doquit='clf(hfig,''reset''),close(''all''),clc,disp(''VIZPLANE is over!'')';

donext='j=j+1;if j==20, hstring=''All views shown. Press QUIT.'';';
donext=[donext 'title(hstring,''color'',''r'', ''fontweight'',''bold'',''fontsize'',16);'];
donext=[donext 'delete(viewbut),delete(butfrmv),'];
donext=[donext 'else,view(-30-(j-1)*20,el);'];
donext=[donext 'hstring=[''Moving around the z-axis; view = '', num2str(j),'' ==> Press NEXT VIEW.''];'];
donext=[donext 'title(hstring, ''fontweight'',''bold'',''fontsize'',14);end'];

%setting up a default grid
xx=[-2:.2:2];yy=[-2:.2:2];
[x,y]=meshgrid(xx,yy);
xmax=max(xx);xmin=min(xx);ymax=max(yy);ymin=min(yy);

goodch='N';
while goodch=='N'
   clc
   help vizplane
   disp(menu)
   ch=input(choice);
   if ch==0 | ch==1 | ch==2 | ch==3 | ch==4 | ch==5
      goodch='Y';
   end
end
if ch==0,clc,disp('VIZPLANE is over!'),return,end

%THE DEMOS
if ch==1    %No intersection points
   el=20;
   fz1=4+5*x-y;nz1='5x - y -z = -4';
   fz2=fz1-10;nz2='5x - y -z = 6';
   fz3=3*y-2*x;nz3='2x -3y + z = 0';
end

if ch==2     %Intersect in a line
   el=10;
   fz1=(7-2*x+4*y)/4;nz1='2x - 4y + 4z =7';
   fz2=(2-6*x-2*y)/(-3);nz2='6x + 2y - 3z = 2';
   fz3=(5+4*x+6*y)/(8);nz3='-4x - 6y + 8z = 5';
   %fz1=(6-4*x-2*y)/(-3);nz1='4x + 2y - 3z = 6';
   %fz2=y-x;nz2 = 'x - y - z = 0';
   %fz3=(6-5*x-y)/(-4);nz3='5x + y - 4z = 6';
   %fz3=(6-2*x-4*y)/(-5);nz3='2x - 4y - 5z = 6';
end
   
if ch==3    %intersect in point
   el=10;
   fz1=(8-2*x+y)/4; nz1='2x - y + 4z = 8';
   fz2=4-x-6*y;nz2='x + 6y + z = 4';
   fz3=(25-25*x+2*y)/(-13);nz3='25x - 2y - 13 z = 25';
end

if ch==4   %intersect in point
   el=30;
   xx=[0:.1:2];yy=[0:.1:2];
   [x,y]=meshgrid(xx,yy);
   xmax=max(xx);xmin=min(xx);ymax=max(yy);ymin=min(yy);
   fz1=4-4*x+y; nz1='4x - y + z = 4';
   fz2=(2-2*x-y)*(-1);nz2='2x + y - z = 2';
   fz3=-x+2*y;nz3='x - 2y + z = 0';
end

if ch==5   %no intersection points
   el=10;
   fz1=10-x-y;nz1='x + y + z = 10';
   fz2=0-x-y;nz2 = 'x + y + z = 0';
   fz3=6-3*x+4*y;nz3='3x - 2y + z = 9';
end

%Setting up colors for the three planes
%
[m1,n1]=size(fz1);
   Cred(:,:,1)=ones(m1,n1);Cred(:,:,2)=zeros(m1,n1);Cred(:,:,3)=zeros(m1,n1);
   Cgreen(:,:,1)=zeros(m1,n1);Cgreen(:,:,2)=ones(m1,n1);Cgreen(:,:,3)=zeros(m1,n1);
   Cblue(:,:,1)=zeros(m1,n1);Cblue(:,:,2)=zeros(m1,n1);Cblue(:,:,3)=ones(m1,n1);

%DOING THE GRAPHICS
%setting graphics window to full size
hfig=figure('units','normal','position',[0 0 1 1]);
axis('off')

%subplots
axhead=subplot('position',[.425 .95 .25 .1]);axis('off')   %header
vanbox=subplot('position',[.05,.07,.05,.05]);axis('off')

%header
subplot(axhead)
text(0,0,header,'color','m',...
     'fontweight','bold','fontsize',20);

%vanity
subplot(vanbox)
text(0,0,'by D.R.Hill','color','k','fontangle','oblique',...
     'fontweight','bold','fontsize',14);

  %figure
   subplot(221),surf(x,y,fz1,Cred),hold on
   title([nz1],'fontweight','bold','fontsize',14)
   plot3([xmin xmax],[0 0],[0 0],'-k')
   plot3([0 0],[ymin ymax],[0 0],'-k')
   plot3([0 0],[0 0],[min(min(fz1)) max(max(fz1))],'-k','linewidth',2)
   pause(2)
   subplot(222),surf(x,y,fz2,Cgreen),hold on
   title([ nz2],'fontweight','bold','fontsize',14)
   plot3([xmin xmax],[0 0],[0 0],'-k')
   plot3([0 0],[ymin ymax],[0 0],'-k')
   plot3([0 0],[0 0],[min(min(fz2)) max(max(fz2))],'-k','linewidth',2)
   subplot(223),surf(x,y,fz3,Cblue),hold on
   title([ nz3],'fontweight','bold','fontsize',14)
   plot3([xmin xmax],[0 0],[0 0],'-k')
   plot3([0 0],[ymin ymax],[0 0],'-k')
   plot3([0 0],[0 0],[min(min(fz3)) max(max(fz3))],'-k','linewidth',2)
   pause(2)
   subplot(224),surf(x,y,fz1,Cred),hold on, surf(x,y,fz2,Cgreen),surf(x,y,fz3,Cblue)
   title('All three planes.','fontweight','bold','fontsize',14)
   plot3([xmin xmax],[0 0],[0 0],'-k')
   plot3([0 0],[ymin ymax],[0 0],'-k')
   zmin=min([min(min(fz1)) min(min(fz2)) min(min(fz3))]);
   zmax=max([max(max(fz1)) max(max(fz2)) max(max(fz3))]);
   plot3([0 0],[0 0],[zmin zmax],'-k','linewidth',2)
   pause(2)
   xlabel('Press Enter.','fontweight','bold','fontsize',14)%,pause
   drawnow,pause,clf(hfig,'reset')
%start the LOOKING process
%
%setting graphics window to full size
hfig=figure('units','normal','position',[0 0 1 1]);
axis('off')

butfrm=uicontrol('style','frame','units','normal',...
                 'position',[.05 .29 .12 .08],'backgroundcolor','y');

viewbut=uicontrol('style','push','units','normal','pos',[.06 .3 .1 .06], ...
        'string','QUIT','fontsize',14,'call',doquit);

butfrmv=uicontrol('style','frame','units','normal',...
                 'position',[.05 .39 .12 .08],'backgroundcolor','r');

viewbut=uicontrol('style','push','units','normal','pos',[.06 .4 .1 .06], ...
        'string','NEXT VIEW','fontsize',14,'call',donext);

%subplots
axhead=subplot('position',[.45 .95 .25 .1]);axis('off')   %header
grbox=subplot('position',[.35,.15,.65,.65]); %graphics box
eqnbox=subplot('position',[.05,.75,.2,.2]);axis('off');  %equation box
vanbox=subplot('position',[.05,.07,.05,.05]);axis('off')


%Showing the header
subplot(axhead)
text(0,0,header,'color','m',...
     'fontweight','bold','fontsize',22);
%Showing the Equations
subplot(eqnbox)
text(0,.6,nz1,'color','r',...
     'fontweight','bold','fontsize',18);
text(0,.3,nz2,'color','g',...
     'fontweight','bold','fontsize',18);
text(0,0,nz3,'color','b',...
     'fontweight','bold','fontsize',18);
%vanity
subplot(vanbox)
text(0,0,'by D.R.Hill','color','k','fontangle','oblique','fontweight','bold','fontsize',14)
     


%Do the plots
subplot(grbox)
   surf(x,y,fz1,Cred),hold on, surf(x,y,fz2,Cgreen),surf(x,y,fz3,Cblue)
   plot3([xmin xmax],[0 0],[0 0],'-k')
   plot3([0 0],[ymin ymax],[0 0],'-k')
   zmin=min([min(min(fz1)) min(min(fz2)) min(min(fz3))]);
   zmax=max([max(max(fz1)) max(max(fz2)) max(max(fz3))]);
   plot3([0 0],[0 0],[zmin zmax],'-k','linewidth',2)
   pause(2)

return
   for j=1:19;
      view(-30-(j-1)*20,el)
      hstring=['z-axis view = ' num2str(j),'. Press NEXT VIEW.'];
      title(hstring, 'fontweight','bold','fontsize',12)
      pause
   end
   hstring='All views shown. Press QUIT.';
   title(hstring,'color','r', 'fontweight','bold','fontsize',14)