function weather(A,w,num) %updated 9/14/98; 6/26/2015
%WEATHER   A demonstration of a Markov Process using a Weather Model.
%          At Perfect City the weather is either sunny, cloudy, or rainy. 
%          The day-to-day change from one type of weather to another      
%          is controlled by a transition probability which is an entry    
%          of a 3 by 3 matrix A, called a transition matrix. Once we      
%          know the vector w of probabilities for today''s weather we      
%          compute the probability vector for tomorrow''s weather from     
%          the matrix product A*w. We use this process repeatedly to      
%          determine the weather probabilities for future days.                    
%
%          Use in the form  --> weather  <-- and you willbe prompted for input
%          or the form      --> weather(A,w,num)  <---
%                           where A is a 3 by 3 transition matrix
%                                 w is a 3 by 1 probability vector 
%                                   for today's weather
%                                num is the number of days of weather 
%                                   distributions to predict        
%
%
%  By: David R. Hill, Math Dept, Temple University,
%      Philadelphia, Pa. 19122   Email: dhill001@temple.edu

%strings
over='WEATHER Model routine is over.';
menu1=['CHOICES:                         ';
       '                                 ';
       '1. Use the Markov weather model. ';
       '                                 ';
       '0. QUIT                          '];
menu2=['1. See the predictions in format short.                 ';
       '                                                        ';
       '2. See the predictions in format long.                  ';
       '                                                        ';
       '3. Show the behavior of the predictions graphically.    ';
       '                                                        ';
       '0. QUIT.                                                '];

s0=' ';
header='The WEATHER Model; a Markov Process';
choice='ENTER your choice:  -->  ';
story=['At Perfect City the weather is either sunny, cloudy, or rainy.';
       'The day-to-day change from one type of weather to another     ';
       'is controlled by a transition probability which is an entry   ';
       'of a 3 by 3 matrix A, called a transition matrix. Once we     ';
       'know the vector w of probabilities for today''s weather we     ';
       'compute the probability vector for tomorrow''s weather from    ';
       'the matrix product A*w. We use this process repeatedly to     ';
       'determine the weather probabilities for future days.          ';
       '                                                              ';
       '   Today''s weather probability vector = w                     ';
       '   Tomorrow''s weather probability vector = A*w                ';
       '   The next day''s weather probability vector = A*A*w          ';
       '   and so on.                                                 ';
       '                                                              ';
       'This type of procedure is called a Markov process (or chain) .';
       'We are interested in the long term behavior of the weather    ';
       'in the sense that we want to know the probability vector      ';
       'which describes the chances of sunny, cloudy, or rainy        ';
       'weather.                                                      '];
    
again='Improper choice; TRY again. Press ENTER.';
cont='Press ENTER to continue.';
ch=2;%signal that input came via parameter list

if nargin==0,
   goodch='N';
   while goodch=='N'
      clc,disp(header)
      disp(s0),disp(story),disp(menu1)
      ch=input(choice);
      if isempty(ch)==1
         ch=999;
      end   
      if ch==0,clc,disp(over),return,end
      if ch==1,goodch='Y';end
      if ch~=0 & ch~=1,disp(again),pause,end
   end
end

if ch==1
   goodA='N';
   while goodA=='N'
      clc,disp(header)
      disp('Enter a 3 by 3 tansition matrix')
      A = input('A = ');
      if isempty(A)==1
         A=[];
      end   

      A=abs(A);
      [m,n]=size(A);
      if m==3 & n==3
         goodA='M';
      else
        disp('Matrix A is not 3 by 3; Press Enter to retry.')
        pause
      end
      if goodA=='M'
         if (sum(sum(A))-3)<1.E-10   %to account for fractions & roundoff
            goodA='Y';
         else
            disp('Matrix A is not a transition matrix; Press ENTER to retry.')
            goodA='N';
            pause
         end
      end
   end
   goodw='N';
   while goodw=='N'
      clc,disp('Your transition matrix is:'),disp(A)
      disp('Next enter today''s weather probabilities as a 3 by 1 matrix.')
      w=input('Initial vector w = ');
      if isempty(w)==1
         w=[];
      end   

      w=abs(w);
      [m,n]=size(w);
      if m==3 & n==1
         goodw='M';
      elseif m==1 & n==3
         w=w';goodw='M';
      else
         disp('Initial vector is wrong size; Press ENTER to retry.')
         pause
      end
      if goodw=='M'
         if abs(sum(w)-1)<1.e-10  %to account for things like 1/3 & 1/6
            goodw='Y';            %round off
         else
            disp('Vector w is not a probability vector; Press ENTER to retry.')
            goodw='N';
            pause
         end
      end
   end
   goodnum='N';
   while goodnum=='N'
      disp('Enter the number of days to predict the weather vector for.')
      num=input('Number of days =  ');
      if isempty(num)==1
         num=-999;
      end   

      if num<0 | num~=abs(num) |num~=fix(num)
         disp('Number of days must be an integer > 0.')
         disp('Press ENTER to retry.')
         pause
      else
         goodnum='Y';
      end
   end
end    
   
if ch==2
   errsw='OFF';
   A=abs(A);
   [m,n]=size(A);
   if m~=3 | n~=3,errsw='ONN';end
   if sum(sum(A))~=3,errsw='ONN';end
   if sum(w)~=1,errsw='ONN';end
   [m,n]=size(w);
   if m~=3 | n~=1,errsw='ONN';end
   if num<0 | num~=abs(num) |num~=fix(num),errsw='ONN';end
   if errsw=='ONN'
      clc
      disp('ERROR in input data to WEATHER.')
      disp('check your data and try again.')
      disp(over)
      return
   end
end
 
origw=w;     
data=w;
for jj=1:num
   w=A*w;data=[data w];
end


quitsw='N';
while quitsw=='N'
   clc,disp(header)
   disp('Your transition matrix is:'),disp(A)
   disp('The initial weather vector was:'),disp(origw)
   disp(['After ' num2str(num) ' steps the weather vector is:']),disp(data(:,num+1))
   disp(s0),disp(menu2),disp(s0)
   ch=input(choice);
   if isempty(ch)==1
         ch=999;
   end   

   if ch==0,quitsw=='Y';clc,disp(over),return,end
   if ch==1,format short,disp('PREDICTIONS:'),disp(data),disp(s0),disp(cont),pause,end
   if ch==2,format long,disp('PREDICTIONS:'),disp(data),disp(s0),disp(cont),pause,format,end
   if ch==3
       x=[1:num+1];
       figure,plot(x,data(1,:),'*-r',x,data(2,:),'*-b',x,data(3,:),'*-m')
       title('Behavior of the WEATHER MODEL      Press ENTER to continue.')
       xlabel('red = sunny data;  blue = cloudy data;  magenta = rainy data')
       pause
       delete(gcf)
   end
   if ch~=0 & ch~=1 & ch~=2 & ch~=3   
      disp(again),pause
   end
end



